@@ -6,7 +6,7 @@
 
 /***************************************************************************
     This file is part of MIXMOD
-    
+
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,63 +20,60 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org                                                                                               
+    All informations available on : http://www.mixmod.org
 ***************************************************************************/
 
 #include "mixmod/DiscriminantAnalysis/Learn/LearnMain.h"
 #include "mixmod/DiscriminantAnalysis/Learn/LearnInput.h"
-#include "mixmod/DiscriminantAnalysis/Learn/LearnOutput.h"
 #include "mixmod/DiscriminantAnalysis/Learn/LearnModelOutput.h"
+#include "mixmod/DiscriminantAnalysis/Learn/LearnOutput.h"
 #include "mixmod/DiscriminantAnalysis/Learn/LearnStrategy.h"
-#include "mixmod/Utilities/Random.h"
-#include "mixmod/Kernel/IO/BinaryData.h"
-#include "mixmod/Kernel/IO/LabelDescription.h"
-#include "mixmod/Kernel/Model/Model.h"
-#include "mixmod/Kernel/Model/BinaryModel.h"
-#include "mixmod/Utilities/Error.h"
-#include "mixmod/Kernel/IO/Partition.h"
 #include "mixmod/Kernel/Criterion/BICCriterion.h"
 #include "mixmod/Kernel/Criterion/CVCriterion.h"
+#include "mixmod/Kernel/IO/BinaryData.h"
+#include "mixmod/Kernel/IO/LabelDescription.h"
 #include "mixmod/Kernel/IO/ModelOutput.h"
+#include "mixmod/Kernel/IO/Partition.h"
+#include "mixmod/Kernel/Model/BinaryModel.h"
+#include "mixmod/Kernel/Model/Model.h"
+#include "mixmod/Utilities/Error.h"
+#include "mixmod/Utilities/Random.h"
 #include <ctime>
 
-namespace XEM {
+namespace XEM
+{
 
 //------------
 // Constructor
 //------------
-LearnMain::LearnMain() {
-	THROW(OtherException, internalMixmodError);
-}
+LearnMain::LearnMain() { THROW(OtherException, internalMixmodError); }
 
 //------------
 // Constructor
 //------------
-LearnMain::LearnMain(LearnInput * input, LearnOutput * output)
-: _input(input), _output(output) {
-}
+LearnMain::LearnMain(LearnInput *input, LearnOutput *output) : _input(input), _output(output) {}
 
 //-----------
 // Destructor
 //-----------
-LearnMain::~LearnMain() {
-	if (_output) {
-		delete _output;
-	}
+LearnMain::~LearnMain()
+{
+	delete _output;
 }
 
 //---
-//run
+// run
 //---
-void LearnMain::run(int seed, IoMode iomode, int verbose, int massiccc) {
+void LearnMain::run(int seed, IoMode iomode, int verbose, int massiccc)
+{
 	//--------------------------------------------------------------------
 	// Important : Call randomize function to change random seed or not ...
 	//---------------------------------------------------------------------
-	
-//TODO: naming conventions ? (this doesn't look good)
+
+	// TODO: naming conventions ? (this doesn't look good)
 	IOMODE = iomode;
 	VERBOSE = verbose;
-  MASSICCC = massiccc;
+	MASSICCC = massiccc;
 
 	initRandomize(seed);
 
@@ -100,76 +97,71 @@ void LearnMain::run(int seed, IoMode iomode, int verbose, int massiccc) {
 	int64_t nbCluster = vNbCluster[0];
 
 	// get data
-	Data * inputData = (_input->getDataDescription()).getData();
+	Data *inputData = (_input->getDataDescription()).getData();
 
 	// get labels
-	Partition * inputKnownPartition = new Partition(
-			_input->getKnownLabelDescription()->getLabel(), vNbCluster[0]);
+	Partition *inputKnownPartition = new Partition(_input->getKnownLabelDescription()->getLabel(), vNbCluster[0]);
 
 	// define a new Learn Strategy
 	LearnStrategy learnStrategy;
 
 	// Define a vector of models
-	std::vector<Model*> estimations(nbEstimation);
+	std::vector<Model *> estimations(nbEstimation);
 
 	// create model for binary data
 	if (_input->getDataType() == QualitativeData && DATA_REDUCE) {
 
-		Data * workingData = inputData;
-		Partition * workingKnownPartition = inputKnownPartition;
+		Data *workingData = inputData;
+		Partition *workingKnownPartition = inputKnownPartition;
 		std::vector<int64_t> correspondenceOriginDataToReduceData;
 		//------------
-		//Reduce Data
+		// Reduce Data
 		//------------
-		BinaryData * bData = dynamic_cast<BinaryData*> (inputData);
+		BinaryData *bData = dynamic_cast<BinaryData *>(inputData);
 
 		// initPartition
-		Partition * inputInitPartition = NULL;
-		Partition * workingInitPartition = NULL;
+		Partition *inputInitPartition = nullptr;
+		Partition *workingInitPartition = nullptr;
 
 		try {
-			//TODO RD : data ne doit pas forcément etre recréé
-			workingData = bData->reduceData(correspondenceOriginDataToReduceData, 
-					inputKnownPartition, inputInitPartition, 
-					workingKnownPartition, workingInitPartition);
+			// TODO RD : data ne doit pas forcément etre recréé
+			workingData = bData->reduceData(correspondenceOriginDataToReduceData, inputKnownPartition, inputInitPartition,
+			                                workingKnownPartition, workingInitPartition);
 			/* TODO ?:
-			 if inputKnownPartition : delete workingKnownPartition 
+			 if inputKnownPartition : delete workingKnownPartition
 			 if inputInitPartition : delete workingStrategy, workingInitPartition
-       
+
 			 */
-		}
-		catch (Exception&errorType) {
-			workingData = NULL;
+		} catch (const Exception &) {
+			workingData = nullptr;
 			throw;
 		}
 		// fin de ReduceData
-		
+
 		// create tabEstmation[iEstimation]
 		//--------------------------------
 		for (int iModelType = 0; iModelType < nbModelType; iModelType++) {
-			ModelType * modelType = _input->getModelType()[iModelType];
-			estimations[iModelType] = new BinaryModel(modelType, nbCluster, workingData, 
-					workingKnownPartition, correspondenceOriginDataToReduceData);
+			ModelType *modelType = _input->getModelType()[iModelType];
+			estimations[iModelType] = new BinaryModel(modelType, nbCluster, workingData, workingKnownPartition,
+			                                          correspondenceOriginDataToReduceData);
 		}
 	}
-		// create model for quantitative data
+	// create model for quantitative data
 	else if (_input->getDataType() == QuantitativeData) {
 		// loop over all models
 		for (int iModelType = 0; iModelType < nbModelType; iModelType++) {
-			ModelType * modelType = _input->getModelType()[iModelType];
+			ModelType *modelType = _input->getModelType()[iModelType];
 			// create new estimation
-			estimations[iModelType] = 
-					new Model(modelType, nbCluster, inputData, inputKnownPartition);
+			estimations[iModelType] = new Model(modelType, nbCluster, inputData, inputKnownPartition);
 		}
 	}
-		//create model for heterogeneous data
+	// create model for heterogeneous data
 	else {
 		// loop over all models
 		for (int iModelType = 0; iModelType < nbModelType; iModelType++) {
-			ModelType * modelType = _input->getModelType()[iModelType];
+			ModelType *modelType = _input->getModelType()[iModelType];
 			// create new estimation
-			estimations[iModelType] = 
-					new Model(modelType, nbCluster, inputData, inputKnownPartition);
+			estimations[iModelType] = new Model(modelType, nbCluster, inputData, inputKnownPartition);
 		}
 	}
 	// release memory
@@ -183,19 +175,17 @@ void LearnMain::run(int seed, IoMode iomode, int verbose, int massiccc) {
 	while (iEstimation < nbEstimation) {
 		try {
 			learnStrategy.run(estimations[iEstimation]);
-		}
-		catch (Exception&errorType) {
-			
+		} catch (Exception & errorType) {
+
 			if (VERBOSE == 1) {
 				Error error(errorType);
 				error.run();
 			}
-			
+
 			// set error for that model
 			estimations[iEstimation]->setError(errorType);
-		}
-		catch (...) {
-			Exception * unknown = new OtherException(UnknownReason);
+		} catch (...) {
+			Exception *unknown = new OtherException(UnknownReason);
 			estimations[iEstimation]->setError(*unknown);
 			delete unknown;
 		}
@@ -209,9 +199,9 @@ void LearnMain::run(int seed, IoMode iomode, int verbose, int massiccc) {
 	// 3. run Selections
 	//-------------------
 	// get criterion names
-	std::vector<CriterionName> const & criterion = _input->getCriterionName();
+	std::vector<CriterionName> const &criterion = _input->getCriterionName();
 
-	// Initialize timer info	
+	// Initialize timer info
 	time_t startTime;
 	ofstream progressFile;
 	if (MASSICCC == 1) {
@@ -225,90 +215,84 @@ void LearnMain::run(int seed, IoMode iomode, int verbose, int massiccc) {
 			// loop over criterion name
 			for (unsigned int iCriterion = 0; iCriterion < criterion.size(); iCriterion++) {
 				switch (criterion[iCriterion]) {
-				case BIC:
-				{
+				case BIC: {
 					// create BIC criterion
 					BICCriterion bic(estimations[iModel]);
 					// compute criterion outputs
 					bic.run(_output->getLearnModelOutput(iModel)->getCriterionOutput(BIC));
 					break;
 				}
-				case CV:
-				{
+				case CV: {
 					// create CV criterion
 
 					CVCriterion cv(estimations[iModel], _input->getNbCVBlock());
 					// compute criterion outputs
 					cv.run(_output->getLearnModelOutput(iModel)->getCriterionOutput(CV));
 					// add label from CV
-					_output->getLearnModelOutput(iModel)
-							->setCVLabel(estimations[iModel], cv.getCVLabel());
+					_output->getLearnModelOutput(iModel)->setCVLabel(estimations[iModel], cv.getCVLabel());
 					break;
 				}
-				case ICL: THROW(InputException, badCriterion);
-				case NEC: THROW(InputException, badCriterion);
-				case UNKNOWN_CRITERION_NAME: THROW(OtherException, internalMixmodError);
-				default: THROW(OtherException, internalMixmodError);
+				case ICL:
+					THROW(InputException, badCriterion);
+				case NEC:
+					THROW(InputException, badCriterion);
+				case UNKNOWN_CRITERION_NAME:
+					THROW(OtherException, internalMixmodError);
+				default:
+					THROW(OtherException, internalMixmodError);
 				}
 
-        //Write progress in file
-        if (MASSICCC == 1) {
-          progressFile.open ("progress.json");
-          progressFile << "{ \"Progress\" :  " << ((double)iCriterion + 1 + (double)iModel * (double)criterion.size())/((double)criterion.size() * (double)nbEstimation) * 100.0;
-          time_t currTime;
-          time(&currTime);
-          double timePerModel = difftime(currTime, startTime) / ((double)iCriterion + 1 + (double)iModel * (double)criterion.size());
-          progressFile << ", \"Estimated remaining time\" : " << timePerModel * (criterion.size() - iCriterion - 1) +  (nbEstimation - iModel - 1) * criterion.size() * timePerModel << " } ";
-          progressFile.close();
-        }
+				// Write progress in file
+				if (MASSICCC == 1) {
+					progressFile.open("progress.json");
+					progressFile << "{ \"Progress\" :  "
+					             << ((double)iCriterion + 1 + (double)iModel * (double)criterion.size()) /
+					                    ((double)criterion.size() * (double)nbEstimation) * 100.0;
+					time_t currTime;
+					time(&currTime);
+					double timePerModel =
+					    difftime(currTime, startTime) / ((double)iCriterion + 1 + (double)iModel * (double)criterion.size());
+					progressFile << ", \"Estimated remaining time\" : "
+					             << timePerModel * (criterion.size() - iCriterion - 1) +
+					                    (nbEstimation - iModel - 1) * criterion.size() * timePerModel
+					             << " } ";
+					progressFile.close();
+				}
 
-      } // end iCriterion
-    }
-		else { // set criterion error
+			}    // end iCriterion
+		} else { // set criterion error
 			// loop over criterion name
 			for (unsigned int iCriterion = 0; iCriterion < criterion.size(); iCriterion++) {
-				_output->getLearnModelOutput(iModel)->setCriterionOutput(CriterionOutput(
-						criterion[iCriterion], 0.0, estimations[iModel]->getErrorType()));
+				_output->getLearnModelOutput(iModel)->setCriterionOutput(
+				    CriterionOutput(criterion[iCriterion], 0.0, estimations[iModel]->getErrorType()));
 			} // end iCriterion
 		}
-    //Compute Entropy if needed (for massiccc's visualization)
-    if (MASSICCC == 1 || MASSICCC == 10 || MASSICCC == 11) {
-      vector< vector<double> > entropyM = estimations[iModel]->getEntropyMatrix();
-      int nbVariables = estimations[iModel]->getData()->getPbDimension();
-      ofstream entropyFile;
-      entropyFile.open ("entropy" + std::to_string(iModel + 1) + ".txt");
-      for (int j = 0; j < nbVariables; j++) {
-        for (int l = 0; l < nbCluster; l++) {
-          entropyFile << entropyM[j][l] << "  ";
-        }
-        entropyFile << endl;
-      } 
-      entropyFile.close();
-    }
+		// Compute Entropy if needed (for massiccc's visualization)
+		if (MASSICCC == 1 || MASSICCC == 10 || MASSICCC == 11) {
+			vector<vector<double>> entropyM = estimations[iModel]->getEntropyMatrix();
+			int nbVariables = estimations[iModel]->getData()->getPbDimension();
+			ofstream entropyFile;
+			entropyFile.open("entropy" + std::to_string(iModel + 1) + ".txt");
+			for (int j = 0; j < nbVariables; j++) {
+				for (int l = 0; l < nbCluster; l++) {
+					entropyFile << entropyM[j][l] << "  ";
+				}
+				entropyFile << endl;
+			}
+			entropyFile.close();
+		}
 
-  }//end iModel
-
-	// release memory
-	// NOTE [bauder, 2013-02-24]: not everything should be released here, 
-	// since line 185 in examples/.../discriminant_analysis_3.cpp
-	// ( "XEMParameterDescription * paramPredict = new XEMParameterDescription ( lMOutput );" )
-	// attempts to use some feature of these estimations.
-	// However, fixing memory management here seems rather subtle.
-	// To be fixed soon [see also mixmodLib#5279]
-	//   for (unsigned int iModel=0; iModel<nbEstimation; iModel++){
-	//     delete estimations[iModel];
-	//     estimations[iModel] = 0;
-	//   }
+	} // end iModel
 }
 
 //------------------------
 // return pointer to Input
 //------------------------
-Input * LearnMain::getInput() {
+Input *LearnMain::getInput()
+{
 	if (_input) {
 		return _input;
-	}
-	else {
+	} else {
 		THROW(OtherException, nullPointerError);
 	}
 }
