@@ -6,7 +6,7 @@
 
 /***************************************************************************
     This file is part of MIXMOD
-    
+
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,29 +20,30 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org                                                                                               
+    All informations available on : http://www.mixmod.org
 ***************************************************************************/
 #ifndef XEMMALGO_H
 #define XEMMALGO_H
 
 #include "mixmod/Kernel/Algo/Algo.h"
 
-namespace XEM {
+namespace XEM
+{
 
 /**
   @brief Derived class of XEMAlgo for M Algorithm
   @author F Langrognet
  */
 
-class MAlgo : public Algo {
+class MAlgo : public Algo
+{
 
 public:
-
 	/// Default constructor
 	MAlgo();
 
 	/// copy constructor
-	MAlgo(const MAlgo & mAlgo);
+	MAlgo(const MAlgo &mAlgo);
 
 	/// Constructor
 	MAlgo(AlgoStopName algoStopName, double epsilon, int64_t nbIteration);
@@ -51,10 +52,10 @@ public:
 	virtual ~MAlgo();
 
 	/// clone
-	Algo * clone() override;
+	Algo *clone() override;
 
 	/// Run method
-	void run(Model *& model) override;
+	void run(Model *&model) override;
 
 	AlgoName getAlgoName() const override;
 
@@ -63,17 +64,11 @@ public:
 	double getEpsilon() const override;
 };
 
-inline AlgoName MAlgo::getAlgoName() const {
-	return M;
-}
+inline AlgoName MAlgo::getAlgoName() const { return M; }
 
-inline double MAlgo::getEpsilon() const {
-	THROW(OtherException, internalMixmodError);
-}
+inline double MAlgo::getEpsilon() const { THROW(OtherException, internalMixmodError); }
 
-inline void MAlgo::setEpsilon(double /*eps*/) {
-	THROW(OtherException, internalMixmodError);
-}
+inline void MAlgo::setEpsilon(double /*eps*/) { THROW(OtherException, internalMixmodError); }
 
 }
 
