@@ -6,7 +6,7 @@
 
 /***************************************************************************
     This file is part of MIXMOD
-    
+
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,29 +20,30 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org                                                                                               
+    All informations available on : http://www.mixmod.org
 ***************************************************************************/
 #ifndef XEMSEMALGO_H
 #define XEMSEMALGO_H
 
 #include "mixmod/Kernel/Algo/Algo.h"
 
-namespace XEM {
+namespace XEM
+{
 
 /**
   @brief Derived class of XEMAlgo for SEM Algorithm(s)
   @author F Langrognet
  */
 
-class SEMAlgo : public Algo {
+class SEMAlgo : public Algo
+{
 
 public:
-
 	/// Default constructor
 	SEMAlgo();
 
 	/// Copy constructor
-	SEMAlgo(const SEMAlgo & semAlgo);
+	SEMAlgo(const SEMAlgo &semAlgo);
 
 	/// Constructor
 	SEMAlgo(AlgoStopName algoStopName, int64_t nbIteration);
@@ -51,10 +52,10 @@ public:
 	virtual ~SEMAlgo();
 
 	/// clone
-	Algo * clone() override;
+	Algo *clone() override;
 
 	/// Run method
-	void run(Model *& model) override;
+	void run(Model *&model) override;
 
 	AlgoName getAlgoName() const override;
 
@@ -65,17 +66,11 @@ public:
 	double getEpsilon() const override;
 };
 
-inline AlgoName SEMAlgo::getAlgoName() const {
-	return SEM;
-}
+inline AlgoName SEMAlgo::getAlgoName() const { return SEM; }
 
-inline double SEMAlgo::getEpsilon() const {
-	THROW(OtherException, internalMixmodError);
-}
+inline double SEMAlgo::getEpsilon() const { THROW(OtherException, internalMixmodError); }
 
-inline void SEMAlgo::setEpsilon(double /*eps*/) {
-	THROW(InputException, wrongAlgoStopName);
-}
+inline void SEMAlgo::setEpsilon(double /*eps*/) { THROW(InputException, wrongAlgoStopName); }
 
 }
 
