@@ -6,7 +6,7 @@
 
 /***************************************************************************
     This file is part of MIXMOD
-    
+
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,7 +20,7 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org                                                                                               
+    All informations available on : http://www.mixmod.org
 ***************************************************************************/
 
 #ifndef XEMDATADESCRIPTION_H
@@ -28,7 +28,8 @@
 
 #include "mixmod/Kernel/IO/Description.h"
 
-namespace XEM {
+namespace XEM
+{
 
 // pre-declaration
 class Data;
@@ -36,44 +37,42 @@ class GaussianData;
 class BinaryData;
 class CompositeData;
 
-/** 
+/**
  \class XEMDataDescription
  @author F. Langrognet
-		@date 2011
-		@brief XEMDataDescription class derived from XEMDescription
+        @date 2011
+        @brief XEMDataDescription class derived from XEMDescription
  */
-class DataDescription : public Description {
+class DataDescription : public Description
+{
 
 public:
-	
 	/// Default constructor
 	DataDescription();
 
-	///constructor by initilization
-	DataDescription(int64_t nbSample, int64_t nbColumn, 
-			std::vector<ColumnDescription *> columnDescription, 
-			FormatNumeric::FormatNumericFile format, 
-			std::string filename, std::string infoName = "");
+	/// constructor by initilization
+	DataDescription(int64_t nbSample, int64_t nbColumn, std::vector<ColumnDescription *> columnDescription,
+	                FormatNumeric::FormatNumericFile format, std::string filename, std::string infoName = "");
 
 	/// constructor with a gaussianData
-	DataDescription(GaussianData * gData);
+	DataDescription(GaussianData *gData);
 
 	/// constructor with a binaryData
-	DataDescription(BinaryData * bData);
+	DataDescription(BinaryData *bData);
 
 	/// constructor with composite data
-	DataDescription(CompositeData * cData);
+	DataDescription(CompositeData *cData);
 
-	///constructor by copy
-	DataDescription(DataDescription & dataDescription);
+	/// constructor by copy
+	DataDescription(DataDescription &dataDescription);
 
 	/// Destructor
 	virtual ~DataDescription();
 
-	///operator=    
-	DataDescription & operator=(const DataDescription & dataDescription);
+	/// operator=
+	DataDescription &operator=(const DataDescription &dataDescription);
 
-	Data * getData() const;
+	Data *getData() const;
 
 	/// is binary Data now changed to GetXEMDataType
 	DataType getDataType() const;
@@ -84,26 +83,19 @@ public:
 	void saveNumericValues(std::string fileName = "");
 
 	void releaseData();
-	
-private:
 
-	Data * _data;
+private:
+	Data *_data;
 
 	/// Create and return XEMData *
-	Data * createData() const;
+	Data *createData() const;
 };
 
-inline Data * DataDescription::getData() const {
-	return _data;
-}
+inline Data *DataDescription::getData() const { return _data; }
 
-inline void DataDescription::saveNumericValues(std::string /*fileName*/) {
-	THROW(OtherException, internalMixmodError);
-}
+inline void DataDescription::saveNumericValues(std::string /*fileName*/) { THROW(OtherException, internalMixmodError); }
 
-inline void DataDescription::releaseData(){
-	_data = NULL;
-}
+inline void DataDescription::releaseData() { _data = NULL; }
 
 }
 
