@@ -6,7 +6,7 @@
 
 /***************************************************************************
     This file is part of MIXMOD
-    
+
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,21 +20,23 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org                                                                                               
+    All informations available on : http://www.mixmod.org
 ***************************************************************************/
 
 #include "mixmod/Kernel/IO/Input.h"
 #include "mixmod/Kernel/IO/Data.h"
-#include "mixmod/Kernel/IO/Partition.h"
 #include "mixmod/Kernel/IO/LabelDescription.h"
+#include "mixmod/Kernel/IO/Partition.h"
 #include "mixmod/Kernel/Model/ModelType.h"
 
-namespace XEM {
+namespace XEM
+{
 
 //--------------------
 // Default Constructor
 //--------------------
-Input::Input() {
+Input::Input()
+{
 	_nbSample = 0;
 	_pbDimension = 0;
 	_nbCluster.clear();
@@ -47,46 +49,46 @@ Input::Input() {
 //-----------------
 // Copy Constructor
 //-----------------
-Input::Input(const Input & input) {
-	_finalized = input._finalized;
+Input::Input(const Input &input)
+{
+	if (this != &input)
+	{
+		_finalized = input._finalized;
 
-	_nbSample = input._nbSample;
-	_pbDimension = input._pbDimension;
-	_nbCluster = input._nbCluster;
+		_nbSample = input._nbSample;
+		_pbDimension = input._pbDimension;
+		_nbCluster = input._nbCluster;
 
-	_dataDescription = (input._dataDescription); // op =
+		_dataDescription = (input._dataDescription); // op =
 
+		if (input._knownPartition != nullptr) {
+			_knownPartition = new Partition(*input._knownPartition);
+		}
 
-	_knownPartition = NULL;
-	if (input._knownPartition != NULL) {
-		_knownPartition = new Partition(input._knownPartition);
+		if (_knownLabelDescription)
+		  delete _knownLabelDescription;
+
+		if (input._knownLabelDescription != nullptr) {
+			_knownLabelDescription = new LabelDescription(*input._knownLabelDescription);
+		}
+
+		_criterionName = input._criterionName;
+		_modelType = input._modelType;
 	}
-
-//if (!_knownLabelDescription) ??
-//  delete _knownLabelDescription;
-
-	_knownLabelDescription = NULL;
-	if (input._knownLabelDescription != NULL) {
-		_knownLabelDescription = new LabelDescription(*input._knownLabelDescription);
-	}
-
-	_criterionName = input._criterionName;
-	_modelType = input._modelType;
-
 }
 
 //---------------------------
 // Initialisation Constructor
 //---------------------------
-Input::Input(const std::vector<int64_t> & iNbCluster, const DataDescription & iDataDescription) {
+Input::Input(const std::vector<int64_t> &iNbCluster, const DataDescription &iDataDescription)
+{
 	cloneInitialisation(iNbCluster, iDataDescription);
 }
 
 //---------------------
-// Clone Initialisation 
+// Clone Initialisation
 //---------------------
-void Input::cloneInitialisation(const std::vector<int64_t> & iNbCluster, 
-		const DataDescription & iDataDescription) 
+void Input::cloneInitialisation(const std::vector<int64_t> &iNbCluster, const DataDescription &iDataDescription)
 {
 	_finalized = false;
 
@@ -107,7 +109,7 @@ void Input::cloneInitialisation(const std::vector<int64_t> & iNbCluster,
 	else{
 	  _modelType.push_back(new ModelType(defaultBinaryModelName));
 	}*/
-	//cout<<_dataDescription.getDataType()<<endl;
+	// cout<<_dataDescription.getDataType()<<endl;
 	switch (_dataDescription.getDataType()) {
 	case QualitativeData:
 		_modelType.push_back(new ModelType(defaultBinaryModelName));
@@ -126,18 +128,17 @@ void Input::cloneInitialisation(const std::vector<int64_t> & iNbCluster,
 //---------------------------------
 // Constructor used in DCV context
 //--------------------------------
-Input::Input(Input * originalInput, CVBlock & learningBlock) {
-	THROW(OtherException, internalMixmodError);
-}
+Input::Input(Input *originalInput, CVBlock &learningBlock) { THROW(OtherException, internalMixmodError); }
 
 //-----------
 // Destructor
 //-----------
-Input::~Input() {
-	if (!_knownPartition) {
+Input::~Input()
+{
+	if (_knownPartition) {
 		delete _knownPartition;
 	}
-	if (!_knownLabelDescription) {
+	if (_knownLabelDescription) {
 		delete _knownLabelDescription;
 	}
 	for (unsigned int i = 0; i < _modelType.size(); i++) {
@@ -146,61 +147,61 @@ Input::~Input() {
 	}
 }
 
-
 //------------
 //------------
 // Modifiers
 //------------
 //------------
 
-
 //------ Criterion  ----//
 
-//getCriterion[i]
+// getCriterion[i]
 //-------------------
-CriterionName Input::getCriterionName(unsigned int index) const {
+CriterionName Input::getCriterionName(unsigned int index) const
+{
 	if (index < _criterionName.size()) {
 		return _criterionName[index];
-	}
-	else {
+	} else {
 		THROW(InputException, wrongCriterionPositionInGet);
 	}
 }
 
 // removeCriterionName
 //--------------------
-void Input::removeCriterion(unsigned int index) {
+void Input::removeCriterion(unsigned int index)
+{
 	if (index < _criterionName.size()) {
 		_criterionName.erase(_criterionName.begin() + index);
-	}
-	else {
+	} else {
 		THROW(InputException, wrongCriterionPositionInRemove);
 	}
 	_finalized = false;
 }
 
-
 //------ modelType  ----//
 
 /// setModel
-void Input::setModel(std::vector<ModelName> const & modelName) {
+void Input::setModel(std::vector<ModelName> const &modelName)
+{
 	// resize vector
 	_modelType.resize(modelName.size());
 	for (unsigned int iModel = 0; iModel < _modelType.size(); iModel++) {
 		// copy vector contents
-      if(_modelType[iModel]) delete _modelType[iModel];
-      _modelType[iModel] = new ModelType(modelName[iModel]);
+		if (_modelType[iModel])
+			delete _modelType[iModel];
+		_modelType[iModel] = new ModelType(modelName[iModel]);
 	}
 }
 
-//setModelType
+// setModelType
 //----------------
-void Input::setModelType(const ModelType * modelType, unsigned int index) {
+void Input::setModelType(const ModelType *modelType, unsigned int index)
+{
 	if (index < _modelType.size()) {
-		if (_modelType[index]) delete _modelType[index];
+		if (_modelType[index])
+			delete _modelType[index];
 		_modelType[index] = new ModelType(*modelType);
-	}
-	else {  
+	} else {
 		THROW(InputException, wrongModelPositionInSet);
 	}
 	_finalized = false;
@@ -208,108 +209,120 @@ void Input::setModelType(const ModelType * modelType, unsigned int index) {
 
 // insertModelType
 //-----------------
-void Input::insertModelType(const ModelType * modelType, unsigned int index) {
-	if (index >= 0 && index <= _modelType.size()) {
+void Input::insertModelType(const ModelType *modelType, unsigned int index)
+{
+	if (index <= _modelType.size()) {
 		_modelType.insert(_modelType.begin() + index, new ModelType(*modelType));
-	}
-	else {
+	} else {
 		THROW(InputException, wrongModelPositionInInsert);
 	}
 	_finalized = false;
 }
 
-
-// add new model type 
-void Input::addModelType(const ModelType * modelType) {
+// add new model type
+void Input::addModelType(const ModelType *modelType)
+{
 	if (getDataType() == QualitativeData)
-  	if (getModelGenre(modelType->getModelName()) != QualitativeModel) return;
-
+		if (getModelGenre(modelType->getModelName()) != QualitativeModel)
+			return;
 
 	if (getDataType() == QuantitativeData)
-		if (getModelGenre(modelType->getModelName()) != QuantitativeModel) return;
+		if (getModelGenre(modelType->getModelName()) != QuantitativeModel)
+			return;
 
 	if (getDataType() == HeterogeneousData)
-		if (getModelGenre(modelType->getModelName()) != HeterogeneousModel) return;
+		if (getModelGenre(modelType->getModelName()) != HeterogeneousModel)
+			return;
 
 	bool found = false;
 	for (unsigned int iModel = 0; iModel < _modelType.size(); iModel++) {
-		if (_modelType[iModel]->getModelName() == modelType->getModelName()) found = true;
+		if (_modelType[iModel]->getModelName() == modelType->getModelName())
+			found = true;
 	}
-	if (!found) _modelType.push_back(new ModelType(*modelType));
+	if (!found)
+		_modelType.push_back(new ModelType(*modelType));
 }
 
 // add new model (modelName -> modelType)
-void Input::addModel(ModelName const modelName) {
+void Input::addModel(ModelName const modelName)
+{
 
 	if (getDataType() == QualitativeData)
-		if (getModelGenre(modelName) != QualitativeModel) return;
+		if (getModelGenre(modelName) != QualitativeModel)
+			return;
 
 	if (getDataType() == QuantitativeData)
-		if (getModelGenre(modelName) != QuantitativeModel) return;
+		if (getModelGenre(modelName) != QuantitativeModel)
+			return;
 
 	if (getDataType() == HeterogeneousData)
-		if (getModelGenre(modelName) != HeterogeneousModel) return;
+		if (getModelGenre(modelName) != HeterogeneousModel)
+			return;
 
 	bool found = false;
 	for (unsigned int iModel = 0; iModel < _modelType.size(); iModel++) {
-		if (_modelType[iModel]->getModelName() == modelName) found = true;
+		if (_modelType[iModel]->getModelName() == modelName)
+			found = true;
 	}
-	if (!found) _modelType.push_back(new ModelType(modelName));
+	if (!found)
+		_modelType.push_back(new ModelType(modelName));
 }
 
 // removeModelType
 //--------------------
-void Input::removeModelType(unsigned int index) {
+void Input::removeModelType(unsigned int index)
+{
 	if (index < _modelType.size()) {
 		delete _modelType[index];
 		_modelType.erase(_modelType.begin() + index);
-	}
-	else {
+	} else {
 		THROW(InputException, wrongModelPositionInRemove);
 	}
 	_finalized = false;
 }
 
-
 // ---- Weight ----//
 
-//setWeight()
+// setWeight()
 //-----------
-//TODO a enlever
-void Input::setWeight(std::string weightFileName) {
+// TODO a enlever
+void Input::setWeight(std::string weightFileName)
+{
 	//_data->setWeight(weightFileName);
 	_finalized = false;
 }
 
-void Input::setWeight(double* weight) {
+void Input::setWeight(double *weight)
+{
 	// get pointer to Data
-	Data * data = getData();
+	Data *data = getData();
 	data->setWeight(weight);
 	_finalized = false;
 }
 
-//TODO a enlever
-void Input::insertWeight(std::string weightFileName) {
+// TODO a enlever
+void Input::insertWeight(std::string weightFileName)
+{
 	//_data->setWeight(weightFileName);
 	_finalized = false;
 }
 
-//TODO a enlever
-void Input::removeWeight() {
+// TODO a enlever
+void Input::removeWeight()
+{
 	//_data->setWeightDefault();
 	_finalized = false;
 }
 
-
 // ----- KnownPartition ----//
 
 // setKnownPartition
 //------------------
-void Input::setKnownPartition(std::string iFileName) {
+void Input::setKnownPartition(std::string iFileName)
+{
 	if (_nbCluster.size() != 1) {
 		THROW(InputException, badSetKnownPartition);
-	}
-	else {
+	} else {
 		if (_knownPartition) {
 			delete _knownPartition;
 		}
@@ -324,11 +337,11 @@ void Input::setKnownPartition(std::string iFileName) {
 
 // insertKnownPartition
 //---------------------
-void Input::insertKnownPartition(NumericPartitionFile partitionFile) {
+void Input::insertKnownPartition(NumericPartitionFile partitionFile)
+{
 	if (_nbCluster.size() != 1) {
 		THROW(InputException, badSetKnownPartition);
-	}
-	else {
+	} else {
 		if (_knownPartition) {
 			delete _knownPartition;
 		}
@@ -339,35 +352,40 @@ void Input::insertKnownPartition(NumericPartitionFile partitionFile) {
 
 // removeKnownPartition
 //---------------------
-void Input::removeKnownPartition() {
+void Input::removeKnownPartition()
+{
 	if (_knownPartition) {
 		delete _knownPartition;
 	}
 	_finalized = false;
 }
 
-void Input::setKnownLabelDescription(LabelDescription & labeldescription) {
+void Input::setKnownLabelDescription(LabelDescription &labeldescription)
+{
 	removeKnownLabelDescription();
 
 	_knownLabelDescription = new LabelDescription(labeldescription);
 }
-void Input::setKnownLabelDescription(LabelDescription *labeldescription) {
+void Input::setKnownLabelDescription(LabelDescription *labeldescription)
+{
 	removeKnownLabelDescription();
 
 	_knownLabelDescription = labeldescription;
 }
 
-void Input::removeKnownLabelDescription() {
-	if (!_knownLabelDescription)
+void Input::removeKnownLabelDescription()
+{
+	if (_knownLabelDescription)
 		delete _knownLabelDescription;
 
-	_knownLabelDescription = NULL;
+	_knownLabelDescription = nullptr;
 }
 
 // --------
 // finalize
 // --------
-void Input::finalize() {
+void Input::finalize()
+{
 	if (!_finalized) {
 		_finalized = verif();
 	}
@@ -376,14 +394,12 @@ void Input::finalize() {
 // ----------------
 // Verif
 //-----------------
-bool Input::verif() {
+bool Input::verif()
+{
 	bool res = true;
 
 	// verif 1 : required inputs
-	if (_nbSample == 0
-		|| _pbDimension == 0
-		|| _nbCluster.empty())
-	{
+	if (_nbSample == 0 || _pbDimension == 0 || _nbCluster.empty()) {
 		res = false;
 		THROW(InputException, missingRequiredInputs);
 	}
@@ -397,11 +413,12 @@ bool Input::verif() {
 // ----------------
 // print out input
 // ----------------
-void Input::edit(std::ostream & out) const {
+void Input::edit(std::ostream &out) const
+{
 	out << "Models : ";
 	for (unsigned int iModel = 0; iModel < _modelType.size(); iModel++)
-		//out << endl << "  " << ModelNameToString(_modelType[iModel]->getModelName());
-		out << endl <<*(_modelType[iModel]);
+		// out << endl << "  " << ModelNameToString(_modelType[iModel]->getModelName());
+		out << endl << *(_modelType[iModel]);
 	out << std::endl;
 
 	out << "Criterions : ";
