@@ -6,7 +6,7 @@
 
 /***************************************************************************
     This file is part of MIXMOD
-    
+
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,100 +20,98 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org                                                                                               
+    All informations available on : http://www.mixmod.org
 ***************************************************************************/
 #include "mixmod/Kernel/Parameter/GaussianDiagParameter.h"
-#include "mixmod/Kernel/Parameter/GaussianGeneralParameter.h"
-#include "mixmod/Kernel/Parameter/GaussianEDDAParameter.h"
 #include "mixmod/Kernel/IO/GaussianData.h"
 #include "mixmod/Kernel/Model/Model.h"
 #include "mixmod/Kernel/Model/ModelType.h"
+#include "mixmod/Kernel/Parameter/GaussianEDDAParameter.h"
+#include "mixmod/Kernel/Parameter/GaussianGeneralParameter.h"
 #include "mixmod/Matrix/DiagMatrix.h"
 
 #include <memory>
 
-namespace XEM {
+namespace XEM
+{
 
 /****************/
 /* Constructors */
 /****************/
 
-GaussianDiagParameter::GaussianDiagParameter() {
-	THROW(OtherException, wrongConstructorType);
-}
+GaussianDiagParameter::GaussianDiagParameter() { THROW(OtherException, wrongConstructorType); }
 
 //-------------------------------------------------------------------------------------
 // constructor called by XEMModel
 //-------------------------------------------------------------------------------------
-GaussianDiagParameter::GaussianDiagParameter(Model * iModel, ModelType * iModelType) 
-: GaussianEDDAParameter(iModel, iModelType) 
+GaussianDiagParameter::GaussianDiagParameter(Model *iModel, ModelType *iModelType) : GaussianEDDAParameter(iModel, iModelType)
 {
 	int64_t k;
-	_tabLambda = new double [_nbCluster];
-	_tabShape = new DiagMatrix*[_nbCluster];
-	_W = new DiagMatrix(_pbDimension); //Id
+	_tabLambda = new double[_nbCluster];
+	_tabShape = new DiagMatrix *[_nbCluster];
+	_W = new DiagMatrix(_pbDimension); // Id
 	for (k = 0; k < _nbCluster; k++) {
 		_tabLambda[k] = 1.0;
-		_tabShape[k] = new DiagMatrix(_pbDimension); //Id 
+		_tabShape[k] = new DiagMatrix(_pbDimension); // Id
 
-		_tabSigma[k] = new DiagMatrix(_pbDimension); //Id
-		_tabInvSigma[k] = new DiagMatrix(_pbDimension); //Id
-		_tabWk[k] = new DiagMatrix(_pbDimension); //Id
+		_tabSigma[k] = new DiagMatrix(_pbDimension);    // Id
+		_tabInvSigma[k] = new DiagMatrix(_pbDimension); // Id
+		_tabWk[k] = new DiagMatrix(_pbDimension);       // Id
 	}
 }
 //-------------------------------------------------------------------------------------
 // constructor for ParameterDescription (C.Poli)
 //-------------------------------------------------------------------------------------
-GaussianDiagParameter::GaussianDiagParameter(int64_t iNbCluster, int64_t iPbDimension, ModelType * iModelType) 
-: GaussianEDDAParameter(iNbCluster, iPbDimension, iModelType) 
+GaussianDiagParameter::GaussianDiagParameter(int64_t iNbCluster, int64_t iPbDimension, ModelType *iModelType)
+    : GaussianEDDAParameter(iNbCluster, iPbDimension, iModelType)
 {
 	int64_t k;
-	_tabLambda = new double [_nbCluster];
-	_tabShape = new DiagMatrix*[_nbCluster];
-	_W = new DiagMatrix(_pbDimension); //Id
+	_tabLambda = new double[_nbCluster];
+	_tabShape = new DiagMatrix *[_nbCluster];
+	_W = new DiagMatrix(_pbDimension); // Id
 	for (k = 0; k < _nbCluster; k++) {
 		_tabLambda[k] = 1.0;
-		_tabShape[k] = new DiagMatrix(_pbDimension); //Id 
+		_tabShape[k] = new DiagMatrix(_pbDimension); // Id
 
-		_tabSigma[k] = new DiagMatrix(_pbDimension); //Id
-		_tabInvSigma[k] = new DiagMatrix(_pbDimension); //Id
-		_tabWk[k] = new DiagMatrix(_pbDimension); //Id
+		_tabSigma[k] = new DiagMatrix(_pbDimension);    // Id
+		_tabInvSigma[k] = new DiagMatrix(_pbDimension); // Id
+		_tabWk[k] = new DiagMatrix(_pbDimension);       // Id
 	}
 }
 
 //---------------------------------------------------------------------
 // copy Constructor
 //---------------------------------------------------------------------
-GaussianDiagParameter::GaussianDiagParameter(const GaussianDiagParameter * iParameter) 
-: GaussianEDDAParameter(iParameter) 
+GaussianDiagParameter::GaussianDiagParameter(const GaussianDiagParameter *iParameter) : GaussianEDDAParameter(iParameter)
 {
 	int64_t k;
 	_tabLambda = copyTab(iParameter->getTabLambda(), _nbCluster);
-	_tabShape = new DiagMatrix*[_nbCluster];
+	_tabShape = new DiagMatrix *[_nbCluster];
 	_W = new DiagMatrix(_pbDimension);
 	*_W = iParameter->getW();
 
-	Matrix ** iTabSigma = iParameter->getTabSigma();
-	Matrix ** iTabInvSigma = iParameter->getTabInvSigma();
-	Matrix ** iTabWk = iParameter->getTabWk();
-	DiagMatrix ** iTabShape = iParameter->getTabShape();
+	Matrix **iTabSigma = iParameter->getTabSigma();
+	Matrix **iTabInvSigma = iParameter->getTabInvSigma();
+	Matrix **iTabWk = iParameter->getTabWk();
+	DiagMatrix **iTabShape = iParameter->getTabShape();
 
 	for (k = 0; k < _nbCluster; k++) {
 		_tabSigma[k] = new DiagMatrix(_pbDimension);
-		(* _tabSigma[k]) = iTabSigma[k];
+		(*_tabSigma[k]) = iTabSigma[k];
 		_tabInvSigma[k] = new DiagMatrix(_pbDimension);
-		(* _tabInvSigma[k]) = iTabInvSigma[k];
+		(*_tabInvSigma[k]) = iTabInvSigma[k];
 		_tabWk[k] = new DiagMatrix(_pbDimension);
-		(* _tabWk[k]) = iTabWk[k];
+		(*_tabWk[k]) = iTabWk[k];
 		_tabShape[k] = new DiagMatrix(_pbDimension);
-		(* _tabShape[k]) = iTabShape[k];
+		(*_tabShape[k]) = iTabShape[k];
 	}
 }
 
 /**************/
 /* Destructor */
 /**************/
-GaussianDiagParameter::~GaussianDiagParameter() {
+GaussianDiagParameter::~GaussianDiagParameter()
+{
 	int64_t k;
 
 	if (_tabLambda) {
@@ -148,7 +146,8 @@ GaussianDiagParameter::~GaussianDiagParameter() {
 //------------------------
 // reset to default values
 //------------------------
-void GaussianDiagParameter::reset() {
+void GaussianDiagParameter::reset()
+{
 	int64_t k;
 	for (k = 0; k < _nbCluster; k++) {
 		_tabLambda[k] = 1.0;
@@ -160,15 +159,17 @@ void GaussianDiagParameter::reset() {
 /*********/
 /* clone */
 /*********/
-Parameter * GaussianDiagParameter::clone() const {
-	GaussianDiagParameter * newParam = new GaussianDiagParameter(this);
+Parameter *GaussianDiagParameter::clone() const
+{
+	GaussianDiagParameter *newParam = new GaussianDiagParameter(this);
 	return (newParam);
 }
 
 /************/
 /* initUSER */
 /************/
-void GaussianDiagParameter::initUSER(Parameter * iParam) {
+void GaussianDiagParameter::initUSER(Parameter *iParam)
+{
 	GaussianEDDAParameter::initUSER(iParam);
 	updateTabInvSigmaAndDet();
 }
@@ -176,27 +177,28 @@ void GaussianDiagParameter::initUSER(Parameter * iParam) {
 /*******************/
 /* computeTabSigma */
 /*******************/
-void GaussianDiagParameter::computeTabSigma() {
+void GaussianDiagParameter::computeTabSigma()
+{
 	/* Initialization */
-	GaussianData * data = _model->getGaussianData();
-	double * tabNk = _model->getTabNk();
+	GaussianData *data = _model->getGaussianData();
+	double *tabNk = _model->getTabNk();
 	int64_t k;
-	//DiagMatrix * B = new DiagMatrix(_pbDimension);
-	//DiagMatrix * Bk = new DiagMatrix(_pbDimension);
+	// DiagMatrix * B = new DiagMatrix(_pbDimension);
+	// DiagMatrix * Bk = new DiagMatrix(_pbDimension);
 	std::unique_ptr<DiagMatrix> B(new DiagMatrix(_pbDimension));
-	std::unique_ptr<DiagMatrix>Bk(new DiagMatrix(_pbDimension));
+	std::unique_ptr<DiagMatrix> Bk(new DiagMatrix(_pbDimension));
 	double detB = 0.0; // Determinant of matrix B
-	int64_t iter = 5; // Number of iterations in iterative procedure 
+	int64_t iter = 5;  // Number of iterations in iterative procedure
 	//  double detDiagW;         // Determinant of diagonal matrix W
-	double detDiagWk; // Determinant of diagonal matrix Wk
+	double detDiagWk;    // Determinant of diagonal matrix Wk
 	double lambda = 0.0; // Volume
 	double weightTotal = data->_weightTotal;
 	double power = 1.0 / _pbDimension;
 	double det = 0.0;
 	double logDet = 0.0;
-	//double * W_k = new double[_pbDimension];
-	std::unique_ptr<double[]> W_k(new double[_pbDimension]);    
-	double * Shape_k;
+	// double * W_k = new double[_pbDimension];
+	std::unique_ptr<double[]> W_k(new double[_pbDimension]);
+	double *Shape_k;
 	double tmp;
 	int64_t p;
 
@@ -239,14 +241,14 @@ void GaussianDiagParameter::computeTabSigma() {
 			if (_tabLambda[k] < minOverflow)
 				THROW(NumericException, errorSigmaConditionNumber);
 
-			//tabSigma[k] = tabShape[k]*somme(lambda[k])
+			// tabSigma[k] = tabShape[k]*somme(lambda[k])
 			_tabSigma[k]->equalToMatrixMultiplyByDouble(_tabShape[k], _tabLambda[k]);
 		}
 		break;
 
 	case (Gaussian_p_Lk_Bk):
 	case (Gaussian_pk_Lk_Bk):
-		
+
 		for (k = 0; k < _nbCluster; k++) {
 			NumericException error = NumericException(minDeterminantDiagWkValueError);
 			logDet = _tabWk[k]->determinant(error);
@@ -259,14 +261,14 @@ void GaussianDiagParameter::computeTabSigma() {
 			//_tabShape[k] = _tabW[k]/detWk
 			_tabShape[k]->equalToMatrixDividedByDouble(_tabWk[k], detDiagWk);
 
-			//tabSigma[k] = tabShape[k]*tabLambda[k]
+			// tabSigma[k] = tabShape[k]*tabLambda[k]
 			_tabSigma[k]->equalToMatrixMultiplyByDouble(_tabShape[k], _tabLambda[k]);
 		}
 		break;
 
 	case (Gaussian_p_Lk_B):
 	case (Gaussian_pk_Lk_B):
-		
+
 		while (iter) {
 			/* Pb Overflow */
 			for (k = 0; k < _nbCluster; k++) {
@@ -289,7 +291,7 @@ void GaussianDiagParameter::computeTabSigma() {
 			/* Compute Shape[k] and Lambda[k] */
 			for (k = 0; k < _nbCluster; k++) {
 				// W_k      = _tabWk[k]->getDiagonalValue();
-              _tabWk[k]->putDiagonalValueInStore(W_k.get());
+				_tabWk[k]->putDiagonalValueInStore(W_k.get());
 				_tabShape[k]->equalToMatrixDividedByDouble(B.get(), detB);
 				Shape_k = _tabShape[k]->getStore();
 				tmp = 0.0;
@@ -318,15 +320,16 @@ void GaussianDiagParameter::computeTabSigma() {
 	}
 
 	updateTabInvSigmaAndDet();
-	//delete Bk;
-	//delete B;
-	//delete [] W_k;
+	// delete Bk;
+	// delete B;
+	// delete [] W_k;
 }
 
 //-------------------
-//getLogLikelihoodOne
+// getLogLikelihoodOne
 //-------------------
-double GaussianDiagParameter::getLogLikelihoodOne() const {
+double GaussianDiagParameter::getLogLikelihoodOne() const
+{
 
 	/* Compute log-likelihood for one cluster
 	   useful for NEC criterion */
@@ -334,18 +337,18 @@ double GaussianDiagParameter::getLogLikelihoodOne() const {
 	/* Initialization */
 	int64_t nbSample = _model->getNbSample();
 	int64_t i;
-	GaussianData * data = _model->getGaussianData();
+	GaussianData *data = _model->getGaussianData();
 	double logLikelihoodOne; // Log-likelihood for k=1
-	//double * Mean = new double[_pbDimension];
-	std::unique_ptr<double[]> Mean(new double[_pbDimension]);    
-	double ** y = data->_yStore;
-	double * yi;
-	//DiagMatrix * Sigma = new DiagMatrix(_pbDimension);
-	//DiagMatrix * W = new DiagMatrix(_pbDimension, 0.0);
+	// double * Mean = new double[_pbDimension];
+	std::unique_ptr<double[]> Mean(new double[_pbDimension]);
+	double **y = data->_yStore;
+	double *yi;
+	// DiagMatrix * Sigma = new DiagMatrix(_pbDimension);
+	// DiagMatrix * W = new DiagMatrix(_pbDimension, 0.0);
 	std::unique_ptr<DiagMatrix> Sigma(new DiagMatrix(_pbDimension));
 	std::unique_ptr<DiagMatrix> W(new DiagMatrix(_pbDimension, 0.0));
 	double norme;
-	double * weight = data->_weight;
+	double *weight = data->_weight;
 	//  Mean Estimator (empirical estimator)
 	double totalWeight = data->_weightTotal;
 	computeMeanOne(Mean.get(), weight, y, nbSample, totalWeight);
@@ -353,7 +356,7 @@ double GaussianDiagParameter::getLogLikelihoodOne() const {
 
 	/* Compute the Cluster Scattering Matrix W */
 	int64_t p; // parcours
-	double * xiMoinsMuk = data->getTmpTabOfSizePbDimension();
+	double *xiMoinsMuk = data->getTmpTabOfSizePbDimension();
 
 	for (i = 0; i < nbSample; i++) {
 		yi = y[i];
@@ -364,15 +367,15 @@ double GaussianDiagParameter::getLogLikelihoodOne() const {
 	}
 
 	/* Compute determinant of diag(W) */
-	//logDet   = W->detDiag(minDeterminantDiagWValueError); //virtual
-	Sigma->equalToMatrixDividedByDouble(W.get(), totalWeight); //virtual
+	// logDet   = W->detDiag(minDeterminantDiagWValueError); //virtual
+	Sigma->equalToMatrixDividedByDouble(W.get(), totalWeight); // virtual
 
 	// inverse of Sigma
-	//DiagMatrix * SigmaMoins1 = new DiagMatrix(_pbDimension);
-	Matrix * SigmaMoins1_p = NULL;
-	//SigmaMoins1->inverse(Sigma);// virtual
-	Sigma->inverse(SigmaMoins1_p); //construction de SigmaMoins1 dans la fonction inverse
-    std::unique_ptr<Matrix> SigmaMoins1(SigmaMoins1_p);
+	// DiagMatrix * SigmaMoins1 = new DiagMatrix(_pbDimension);
+	Matrix *SigmaMoins1_p = NULL;
+	// SigmaMoins1->inverse(Sigma);// virtual
+	Sigma->inverse(SigmaMoins1_p); // construction de SigmaMoins1 dans la fonction inverse
+	std::unique_ptr<Matrix> SigmaMoins1(SigmaMoins1_p);
 	NumericException error = NumericException(minDeterminantSigmaValueError);
 	double detSigma = Sigma->determinant(error); // virtual
 
@@ -390,24 +393,25 @@ double GaussianDiagParameter::getLogLikelihoodOne() const {
 	logLikelihoodOne += totalWeight * (data->getPbDimensionLog2Pi() + log(detSigma));
 	logLikelihoodOne *= -0.5;
 
-	//delete W;
-	//delete Sigma;
-	//delete SigmaMoins1;
+	// delete W;
+	// delete Sigma;
+	// delete SigmaMoins1;
 
-	//delete[] Mean;
+	// delete[] Mean;
 	return logLikelihoodOne;
 }
 
 //----------------
-//getFreeParameter
+// getFreeParameter
 //----------------
-int64_t GaussianDiagParameter::getFreeParameter() const {
-	int64_t nbParameter; // Number of parameters
-	int64_t k = _nbCluster; // Sample size
+int64_t GaussianDiagParameter::getFreeParameter() const
+{
+	int64_t nbParameter;      // Number of parameters
+	int64_t k = _nbCluster;   // Sample size
 	int64_t d = _pbDimension; // Sample dimension
 
-	int64_t alphaR = k*d; //alpha for for models with Restrainct proportions (Gaussian_p_...)
-	int64_t alphaF = (k * d) + k - 1; //alpha for models with Free proportions (Gaussian_pk_...)
+	int64_t alphaR = k * d;           // alpha for for models with Restrainct proportions (Gaussian_p_...)
+	int64_t alphaF = (k * d) + k - 1; // alpha for models with Free proportions (Gaussian_pk_...)
 
 	switch (_modelType->_nameModel) {
 	case (Gaussian_p_L_B):
