@@ -6,7 +6,7 @@
 
 /***************************************************************************
     This file is part of MIXMOD
-    
+
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,79 +20,75 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org                                                                                               
+    All informations available on : http://www.mixmod.org
 ***************************************************************************/
 #include "mixmod/Kernel/Parameter/GaussianGeneralParameter.h"
-#include "mixmod/Kernel/Parameter/GaussianEDDAParameter.h"
 #include "mixmod/Kernel/IO/GaussianData.h"
 #include "mixmod/Kernel/Model/Model.h"
 #include "mixmod/Kernel/Model/ModelType.h"
+#include "mixmod/Kernel/Parameter/GaussianEDDAParameter.h"
 #include "mixmod/Matrix/DiagMatrix.h"
-#include "mixmod/Matrix/SymmetricMatrix.h"
 #include "mixmod/Matrix/GeneralMatrix.h"
+#include "mixmod/Matrix/SymmetricMatrix.h"
 
-namespace XEM {
+namespace XEM
+{
 
 /****************/
 /* Constructors */
 /****************/
 
-GaussianGeneralParameter::GaussianGeneralParameter() {
-	THROW(OtherException, wrongConstructorType);
-}
+GaussianGeneralParameter::GaussianGeneralParameter() { THROW(OtherException, wrongConstructorType); }
 
 //-------------------------------------------------------------------------------------
 // constructor called by XEMModel
 //-------------------------------------------------------------------------------------
-GaussianGeneralParameter::GaussianGeneralParameter(Model * iModel, ModelType * iModelType) 
-: GaussianEDDAParameter(iModel, iModelType) 
+GaussianGeneralParameter::GaussianGeneralParameter(Model *iModel, ModelType *iModelType)
+    : GaussianEDDAParameter(iModel, iModelType)
 {
 	int64_t k;
-	_tabShape = new DiagMatrix*[_nbCluster];
-	_tabOrientation = new GeneralMatrix*[_nbCluster];
-	_tabLambda = new double [_nbCluster];
-	_W = new SymmetricMatrix(_pbDimension); //Id
+	_tabShape = new DiagMatrix *[_nbCluster];
+	_tabOrientation = new GeneralMatrix *[_nbCluster];
+	_tabLambda = new double[_nbCluster];
+	_W = new SymmetricMatrix(_pbDimension); // Id
 
 	for (k = 0; k < _nbCluster; k++) {
-		_tabShape[k] = new DiagMatrix(_pbDimension); // Id
-		_tabOrientation[k] = new GeneralMatrix(_pbDimension); //Id
+		_tabShape[k] = new DiagMatrix(_pbDimension);          // Id
+		_tabOrientation[k] = new GeneralMatrix(_pbDimension); // Id
 		_tabLambda[k] = 1.0;
-		_tabSigma[k] = new SymmetricMatrix(_pbDimension); //Id
-		_tabInvSigma[k] = new SymmetricMatrix(_pbDimension); //Id
-		_tabWk[k] = new SymmetricMatrix(_pbDimension); //Id
+		_tabSigma[k] = new SymmetricMatrix(_pbDimension);    // Id
+		_tabInvSigma[k] = new SymmetricMatrix(_pbDimension); // Id
+		_tabWk[k] = new SymmetricMatrix(_pbDimension);       // Id
 	}
 
 	__storeDim = _pbDimension * (_pbDimension + 1) / 2;
 }
 
 //-------------------------------------------------------------------------------------
-//constructeur avec une initialisation USER from file
+// constructeur avec une initialisation USER from file
 //-------------------------------------------------------------------------------------
-GaussianGeneralParameter::GaussianGeneralParameter(
-		int64_t iNbCluster, 
-		int64_t iPbDimension, 
-		ModelType * iModelType, 
-		std::string & iFileName)
-: GaussianEDDAParameter(iNbCluster, iPbDimension, iModelType) 
+GaussianGeneralParameter::GaussianGeneralParameter(int64_t iNbCluster, int64_t iPbDimension, ModelType *iModelType,
+                                                   std::string &iFileName)
+    : GaussianEDDAParameter(iNbCluster, iPbDimension, iModelType)
 {
 	int64_t k;
 	__storeDim = _pbDimension * (_pbDimension + 1) / 2;
-	_tabShape = new DiagMatrix*[_nbCluster];
-	_tabOrientation = new GeneralMatrix*[_nbCluster];
-	_tabLambda = new double [_nbCluster];
+	_tabShape = new DiagMatrix *[_nbCluster];
+	_tabOrientation = new GeneralMatrix *[_nbCluster];
+	_tabLambda = new double[_nbCluster];
 
 	for (k = 0; k < _nbCluster; k++) {
-		_tabShape[k] = new DiagMatrix(_pbDimension); //Id
-		_tabOrientation[k] = new GeneralMatrix(_pbDimension); //Id
+		_tabShape[k] = new DiagMatrix(_pbDimension);          // Id
+		_tabOrientation[k] = new GeneralMatrix(_pbDimension); // Id
 		_tabLambda[k] = 1.0;
 
 		// _tabSigma, _tabInvSigma, _tabWk will be initialized in XEMGaussianEDDAparameter
-		_tabInvSigma[k] = new SymmetricMatrix(_pbDimension); //Id
-		_tabSigma[k] = new SymmetricMatrix(_pbDimension); // Id
-		_tabWk[k] = new SymmetricMatrix(_pbDimension); //Id
+		_tabInvSigma[k] = new SymmetricMatrix(_pbDimension); // Id
+		_tabSigma[k] = new SymmetricMatrix(_pbDimension);    // Id
+		_tabWk[k] = new SymmetricMatrix(_pbDimension);       // Id
 		*_tabWk[k] = 1.0;
 	}
-	_W = new SymmetricMatrix(_pbDimension); //Id
+	_W = new SymmetricMatrix(_pbDimension); // Id
 
 	// read parameters in file iFileName//
 	if (iFileName.compare("") != 0) {
@@ -100,7 +96,7 @@ GaussianGeneralParameter::GaussianGeneralParameter(
 		if (!paramFile.is_open()) {
 			THROW(InputException, wrongParamFileName);
 		}
-    input(paramFile);
+		input(paramFile);
 		paramFile.close();
 	}
 
@@ -108,35 +104,31 @@ GaussianGeneralParameter::GaussianGeneralParameter(
 }
 
 //-------------------------------------------------------------------------------------
-//constructeur avec une initialisation USER from file for heterogeneous models
+// constructeur avec une initialisation USER from file for heterogeneous models
 //-------------------------------------------------------------------------------------
-GaussianGeneralParameter::GaussianGeneralParameter(
-		int64_t iNbCluster, 
-		int64_t iPbDimension, 
-		ModelType * iModelType, 
-		std::string & iFileName,
-    int64_t iNbVariable_binary,
-    std::vector< int64_t > inbFactor)
-: GaussianEDDAParameter(iNbCluster, iPbDimension, iModelType) 
+GaussianGeneralParameter::GaussianGeneralParameter(int64_t iNbCluster, int64_t iPbDimension, ModelType *iModelType,
+                                                   std::string &iFileName, int64_t iNbVariable_binary,
+                                                   std::vector<int64_t> inbFactor)
+    : GaussianEDDAParameter(iNbCluster, iPbDimension, iModelType)
 {
 	int64_t k;
 	__storeDim = _pbDimension * (_pbDimension + 1) / 2;
-	_tabShape = new DiagMatrix*[_nbCluster];
-	_tabOrientation = new GeneralMatrix*[_nbCluster];
-	_tabLambda = new double [_nbCluster];
+	_tabShape = new DiagMatrix *[_nbCluster];
+	_tabOrientation = new GeneralMatrix *[_nbCluster];
+	_tabLambda = new double[_nbCluster];
 
 	for (k = 0; k < _nbCluster; k++) {
-		_tabShape[k] = new DiagMatrix(_pbDimension); //Id
-		_tabOrientation[k] = new GeneralMatrix(_pbDimension); //Id
+		_tabShape[k] = new DiagMatrix(_pbDimension);          // Id
+		_tabOrientation[k] = new GeneralMatrix(_pbDimension); // Id
 		_tabLambda[k] = 1.0;
 
 		// _tabSigma, _tabInvSigma, _tabWk will be initialized in XEMGaussianEDDAparameter
-		_tabInvSigma[k] = new SymmetricMatrix(_pbDimension); //Id
-		_tabSigma[k] = new SymmetricMatrix(_pbDimension); // Id
-		_tabWk[k] = new SymmetricMatrix(_pbDimension); //Id
+		_tabInvSigma[k] = new SymmetricMatrix(_pbDimension); // Id
+		_tabSigma[k] = new SymmetricMatrix(_pbDimension);    // Id
+		_tabWk[k] = new SymmetricMatrix(_pbDimension);       // Id
 		*_tabWk[k] = 1.0;
 	}
-	_W = new SymmetricMatrix(_pbDimension); //Id
+	_W = new SymmetricMatrix(_pbDimension); // Id
 
 	// read parameters in file iFileName//
 	if (iFileName.compare("") != 0) {
@@ -144,42 +136,37 @@ GaussianGeneralParameter::GaussianGeneralParameter(
 		if (!paramFile.is_open()) {
 			THROW(InputException, wrongParamFileName);
 		}
-    input(paramFile, iNbVariable_binary, inbFactor);
+		input(paramFile, iNbVariable_binary, inbFactor);
 		paramFile.close();
 	}
 
 	updateTabInvSigmaAndDet(); // method of XEMGaussianParameter
 }
 //-------------------------------------------------------------------------------------
-//constructeur avec une initialisation USER from containers
+// constructeur avec une initialisation USER from containers
 //-------------------------------------------------------------------------------------
-GaussianGeneralParameter::GaussianGeneralParameter(
-		int64_t iNbCluster, 
-		int64_t iPbDimension, 
-		ModelType * iModelType, 
-		double * proportions, 
-		double ** means, 
-		double *** variances)
-: GaussianEDDAParameter(iNbCluster, iPbDimension, iModelType) 
+GaussianGeneralParameter::GaussianGeneralParameter(int64_t iNbCluster, int64_t iPbDimension, ModelType *iModelType,
+                                                   double *proportions, double **means, double ***variances)
+    : GaussianEDDAParameter(iNbCluster, iPbDimension, iModelType)
 {
 	int64_t k;
 	__storeDim = _pbDimension * (_pbDimension + 1) / 2;
-	_tabShape = new DiagMatrix*[_nbCluster];
-	_tabOrientation = new GeneralMatrix*[_nbCluster];
-	_tabLambda = new double [_nbCluster];
+	_tabShape = new DiagMatrix *[_nbCluster];
+	_tabOrientation = new GeneralMatrix *[_nbCluster];
+	_tabLambda = new double[_nbCluster];
 
 	for (k = 0; k < _nbCluster; k++) {
-		_tabShape[k] = new DiagMatrix(_pbDimension); //Id
-		_tabOrientation[k] = new GeneralMatrix(_pbDimension); //Id
+		_tabShape[k] = new DiagMatrix(_pbDimension);          // Id
+		_tabOrientation[k] = new GeneralMatrix(_pbDimension); // Id
 		_tabLambda[k] = 1.0;
 
 		// _tabSigma, _tabInvSigma, _tabWk will be initialized in XEMGaussianEDDAparameter
-		_tabInvSigma[k] = new SymmetricMatrix(_pbDimension); //Id
-		_tabSigma[k] = new SymmetricMatrix(_pbDimension); // Id
-		_tabWk[k] = new SymmetricMatrix(_pbDimension); //Id
+		_tabInvSigma[k] = new SymmetricMatrix(_pbDimension); // Id
+		_tabSigma[k] = new SymmetricMatrix(_pbDimension);    // Id
+		_tabWk[k] = new SymmetricMatrix(_pbDimension);       // Id
 		*_tabWk[k] = 1.0;
 	}
-	_W = new SymmetricMatrix(_pbDimension); //Id
+	_W = new SymmetricMatrix(_pbDimension); // Id
 
 	input(proportions, means, variances);
 
@@ -187,43 +174,44 @@ GaussianGeneralParameter::GaussianGeneralParameter(
 }
 
 //-------------------------------------------------------------------------------------
-//constructeur par copie
+// constructeur par copie
 //-------------------------------------------------------------------------------------
-GaussianGeneralParameter::GaussianGeneralParameter(const GaussianGeneralParameter * iParameter) 
-: GaussianEDDAParameter(iParameter) 
+GaussianGeneralParameter::GaussianGeneralParameter(const GaussianGeneralParameter *iParameter)
+    : GaussianEDDAParameter(iParameter)
 {
 	int64_t k;
 	__storeDim = _pbDimension * (_pbDimension + 1) / 2;
-	_tabShape = new DiagMatrix*[_nbCluster];
-	_tabOrientation = new GeneralMatrix*[_nbCluster];
+	_tabShape = new DiagMatrix *[_nbCluster];
+	_tabOrientation = new GeneralMatrix *[_nbCluster];
 	_tabLambda = new double[_nbCluster];
-	DiagMatrix ** iTabShape = iParameter->getTabShape();
-	GeneralMatrix ** iTabOrientation = iParameter->getTabOrientation();
-	double * iTabLambda = iParameter->getTabLambda();
-	Matrix ** iTabSigma = iParameter->getTabSigma();
-	Matrix ** iTabInvSigma = iParameter->getTabInvSigma();
-	Matrix ** iTabWk = iParameter->getTabWk();
-	_W = new SymmetricMatrix((SymmetricMatrix *) (iParameter->getW()));
+	DiagMatrix **iTabShape = iParameter->getTabShape();
+	GeneralMatrix **iTabOrientation = iParameter->getTabOrientation();
+	double *iTabLambda = iParameter->getTabLambda();
+	Matrix **iTabSigma = iParameter->getTabSigma();
+	Matrix **iTabInvSigma = iParameter->getTabInvSigma();
+	Matrix **iTabWk = iParameter->getTabWk();
+	_W = new SymmetricMatrix((SymmetricMatrix *)(iParameter->getW()));
 
 	for (k = 0; k < _nbCluster; k++) {
 		//_tabInvSigma[k] = NULL;
-		_tabShape[k] = new DiagMatrix(iTabShape[k]); // copy constructor
-		_tabOrientation[k] = new GeneralMatrix(iTabOrientation[k]); // copy constructor   
+		_tabShape[k] = new DiagMatrix(iTabShape[k]);                // copy constructor
+		_tabOrientation[k] = new GeneralMatrix(iTabOrientation[k]); // copy constructor
 		_tabLambda[k] = iTabLambda[k];
 
 		_tabSigma[k] = new SymmetricMatrix(_pbDimension);
-		(* _tabSigma[k]) = iTabSigma[k];
+		(*_tabSigma[k]) = iTabSigma[k];
 		_tabWk[k] = new SymmetricMatrix(_pbDimension);
-		(* _tabWk[k]) = iTabWk[k];
+		(*_tabWk[k]) = iTabWk[k];
 		_tabInvSigma[k] = new SymmetricMatrix(_pbDimension);
-		(* _tabInvSigma[k]) = iTabInvSigma[k];
+		(*_tabInvSigma[k]) = iTabInvSigma[k];
 	}
 }
 
 /**************/
 /* Destructor */
 /**************/
-GaussianGeneralParameter::~GaussianGeneralParameter() {
+GaussianGeneralParameter::~GaussianGeneralParameter()
+{
 	int64_t k;
 
 	if (_tabShape) {
@@ -257,7 +245,7 @@ GaussianGeneralParameter::~GaussianGeneralParameter() {
 	}
 
 	if (_tabSigma) {
-		//cout<<"destructeur gaussgene"<<endl;
+		// cout<<"destructeur gaussgene"<<endl;
 		for (k = 0; k < _nbCluster; k++) {
 			delete _tabSigma[k];
 			_tabSigma[k] = NULL;
@@ -268,7 +256,8 @@ GaussianGeneralParameter::~GaussianGeneralParameter() {
 //------------------------
 // reset to default values
 //------------------------
-void GaussianGeneralParameter::reset() {
+void GaussianGeneralParameter::reset()
+{
 	int64_t k;
 	for (k = 0; k < _nbCluster; k++) {
 		*(_tabShape[k]) = 1.0;
@@ -281,26 +270,28 @@ void GaussianGeneralParameter::reset() {
 /*********/
 /* clone */
 /*********/
-Parameter * GaussianGeneralParameter::clone() const {
-	GaussianGeneralParameter * newParam = new GaussianGeneralParameter(this);
+Parameter *GaussianGeneralParameter::clone() const
+{
+	GaussianGeneralParameter *newParam = new GaussianGeneralParameter(this);
 	return (newParam);
 }
 
 /************/
 /* initUSER */
 /************/
-void GaussianGeneralParameter::initUSER(Parameter * iParam) {
+void GaussianGeneralParameter::initUSER(Parameter *iParam)
+{
 	GaussianEDDAParameter::initUSER(iParam);
 	updateTabInvSigmaAndDet();
 
-	GaussianGeneralParameter * param = (GaussianGeneralParameter *) iParam;
-	DiagMatrix ** iTabShape = param->getTabShape();
-	GeneralMatrix ** iTabOrientation = param->getTabOrientation();
-	double * iTabLambda = param->getTabLambda();
+	GaussianGeneralParameter *param = (GaussianGeneralParameter *)iParam;
+	DiagMatrix **iTabShape = param->getTabShape();
+	GeneralMatrix **iTabOrientation = param->getTabOrientation();
+	double *iTabLambda = param->getTabLambda();
 	int64_t k;
 	for (k = 0; k < _nbCluster; k++) {
-		(*_tabShape[k]) = (iTabShape[k]); // copy constructor
-		(* _tabOrientation[k]) = iTabOrientation[k]; // copy constructor
+		(*_tabShape[k]) = (iTabShape[k]);           // copy constructor
+		(*_tabOrientation[k]) = iTabOrientation[k]; // copy constructor
 		_tabLambda[k] = iTabLambda[k];
 	}
 }
@@ -308,11 +299,12 @@ void GaussianGeneralParameter::initUSER(Parameter * iParam) {
 /***********************/
 /* computeTabSigma_L_C */
 /***********************/
-void GaussianGeneralParameter::computeTabSigma_L_C() {
+void GaussianGeneralParameter::computeTabSigma_L_C()
+{
 	int64_t k;
 	double totalWeight = (_model->getGaussianData())->_weightTotal;
 	for (k = 0; k < _nbCluster; k++) {
-		//Sigma_k = W / totalWeight
+		// Sigma_k = W / totalWeight
 		_tabSigma[k]->equalToMatrixDividedByDouble(_W, totalWeight);
 	}
 }
@@ -320,9 +312,10 @@ void GaussianGeneralParameter::computeTabSigma_L_C() {
 /*************************/
 /* computeTabSigma_Lkk_Ck */
 /*************************/
-void GaussianGeneralParameter::computeTabSigma_Lk_Ck() {
+void GaussianGeneralParameter::computeTabSigma_Lk_Ck()
+{
 	int64_t k;
-	double * tabNk = _model->getTabNk();
+	double *tabNk = _model->getTabNk();
 	for (k = 0; k < _nbCluster; k++) {
 		// Sigma_k = W_k / n_k
 		_tabSigma[k]->equalToMatrixDividedByDouble(_tabWk[k], tabNk[k]);
@@ -332,14 +325,15 @@ void GaussianGeneralParameter::computeTabSigma_Lk_Ck() {
 /************************/
 /* computeTabSigma_L_Ck */
 /************************/
-void GaussianGeneralParameter::computeTabSigma_L_Ck() {
+void GaussianGeneralParameter::computeTabSigma_L_Ck()
+{
 	double lambda = 0.0;
 	int64_t k;
 	double logDet;
-	GaussianData * data = _model->getGaussianData();
+	GaussianData *data = _model->getGaussianData();
 	double totalWeight = data->_weightTotal;
 	double detWk_k, tmp;
-	double * detWk = new double[_nbCluster];
+	double *detWk = new double[_nbCluster];
 
 	try {
 		for (k = 0; k < _nbCluster; k++) {
@@ -350,7 +344,7 @@ void GaussianGeneralParameter::computeTabSigma_L_Ck() {
 			detWk[k] = detWk_k;
 		}
 
-		lambda /= totalWeight; //lambda = somme sur k detWk^(1/pbDimension) / totalWeight
+		lambda /= totalWeight; // lambda = somme sur k detWk^(1/pbDimension) / totalWeight
 		if (lambda < minOverflow) {
 			THROW(NumericException, errorSigmaConditionNumber);
 		}
@@ -358,14 +352,13 @@ void GaussianGeneralParameter::computeTabSigma_L_Ck() {
 		for (k = 0; k < _nbCluster; k++) {
 			_tabLambda[k] = lambda;
 			tmp = detWk[k] / lambda;
-			_tabSigma[k]->equalToMatrixDividedByDouble(_tabWk[k], tmp); //Sigma_k = Wk / tmp
+			_tabSigma[k]->equalToMatrixDividedByDouble(_tabWk[k], tmp); // Sigma_k = Wk / tmp
 		}
 
-		delete [] detWk;
+		delete[] detWk;
 		detWk = NULL;
-	}
-	catch (Exception&errorType) {
-		delete [] detWk;
+	} catch (Exception &errorType) {
+		delete[] detWk;
 		detWk = NULL;
 		throw;
 	}
@@ -374,12 +367,13 @@ void GaussianGeneralParameter::computeTabSigma_L_Ck() {
 /*****************************/
 /* computeTabSigma_L_Dk_A_Dk */
 /*****************************/
-void GaussianGeneralParameter::computeTabSigma_L_Dk_A_Dk() {
+void GaussianGeneralParameter::computeTabSigma_L_Dk_A_Dk()
+{
 
-	//Ma modification
+	// Ma modification
 	int64_t k;
-	GaussianData * data = _model->getGaussianData();
-	DiagMatrix* Shape = new DiagMatrix(_pbDimension, 0.0); //0.0
+	GaussianData *data = _model->getGaussianData();
+	DiagMatrix *Shape = new DiagMatrix(_pbDimension, 0.0); // 0.0
 	double logDet;
 	double detShape;
 	double totalWeight = data->_weightTotal;
@@ -393,13 +387,13 @@ void GaussianGeneralParameter::computeTabSigma_L_Dk_A_Dk() {
 			(*Shape) += _tabShape[k];
 		}
 
-		// Compute determinant of Shape matrix 
+		// Compute determinant of Shape matrix
 		NumericException error = NumericException(minDeterminantShapeValueError);
 		logDet = Shape->determinant(error);
 		detShape = powAndCheckIfNotNull(logDet, 1.0 / _pbDimension);
 
 		for (k = 0; k < _nbCluster; k++) {
-			//determinant de la somme sur k de _tabShape[k] / totalWeight
+			// determinant de la somme sur k de _tabShape[k] / totalWeight
 			_tabLambda[k] = detShape / totalWeight;
 			if (_tabLambda[k] < minOverflow) {
 				THROW(NumericException, errorSigmaConditionNumber);
@@ -411,8 +405,7 @@ void GaussianGeneralParameter::computeTabSigma_L_Dk_A_Dk() {
 		}
 
 		delete Shape;
-	}
-	catch (Exception&errorType) {
+	} catch (Exception &errorType) {
 		delete Shape;
 		throw;
 	}
@@ -421,19 +414,20 @@ void GaussianGeneralParameter::computeTabSigma_L_Dk_A_Dk() {
 /********************************/
 /* computeTabSigma_Lk_Dk_A_Dk() */
 /********************************/
-void GaussianGeneralParameter::computeTabSigma_Lk_Dk_A_Dk() {
+void GaussianGeneralParameter::computeTabSigma_Lk_Dk_A_Dk()
+{
 	int64_t k;
 	int64_t iter = 5;
 
-	DiagMatrix* Shape = new DiagMatrix(_pbDimension); //Id
-	DiagMatrix* S = new DiagMatrix(_pbDimension); //Id
-	double * tabNk = _model->getTabNk();
+	DiagMatrix *Shape = new DiagMatrix(_pbDimension); // Id
+	DiagMatrix *S = new DiagMatrix(_pbDimension);     // Id
+	double *tabNk = _model->getTabNk();
 
-	DiagMatrix ** tabS = new DiagMatrix*[_nbCluster];
-	GeneralMatrix ** tabU = new GeneralMatrix*[_nbCluster];
+	DiagMatrix **tabS = new DiagMatrix *[_nbCluster];
+	GeneralMatrix **tabU = new GeneralMatrix *[_nbCluster];
 	for (k = 0; k < _nbCluster; k++) {
-		tabS[k] = new DiagMatrix(_pbDimension); //Id
-		tabU[k] = new GeneralMatrix(_pbDimension); //Id
+		tabS[k] = new DiagMatrix(_pbDimension);    // Id
+		tabU[k] = new GeneralMatrix(_pbDimension); // Id
 	}
 
 	double logDet;
@@ -442,7 +436,7 @@ void GaussianGeneralParameter::computeTabSigma_Lk_Dk_A_Dk() {
 	try {
 		// SVD Decomposition of Cluster Scattering Matrix (Symmetric) Wk: Wk=U*S*U'
 		for (k = 0; k < _nbCluster; k++) {
-			_tabWk[k] ->computeSVD(tabS[k], tabU[k]);
+			_tabWk[k]->computeSVD(tabS[k], tabU[k]);
 		}
 		while (iter) {
 
@@ -452,13 +446,13 @@ void GaussianGeneralParameter::computeTabSigma_Lk_Dk_A_Dk() {
 				(*Shape) += S;
 			}
 
-			//Compute determinant of Shape matrix 
+			// Compute determinant of Shape matrix
 			NumericException error = NumericException(minDeterminantShapeValueError);
 			logDet = Shape->determinant(error);
 			detShape = powAndCheckIfNotNull(logDet, 1.0 / _pbDimension);
 
 			for (k = 0; k < _nbCluster; k++) {
-				//A=_tabShape = somme sur k 1/lambdak*Shape
+				// A=_tabShape = somme sur k 1/lambdak*Shape
 				_tabShape[k]->equalToMatrixDividedByDouble(Shape, detShape);
 				_tabLambda[k] = _tabWk[k]->trace_this_O_Sm1_O(tabU[k], _tabShape[k]);
 				_tabLambda[k] /= (_pbDimension * tabNk[k]);
@@ -472,7 +466,7 @@ void GaussianGeneralParameter::computeTabSigma_Lk_Dk_A_Dk() {
 
 		for (k = 0; k < _nbCluster; k++) {
 
-			//trace(Wk Dk A^(-1) Dk') / pbDimension*tabNk
+			// trace(Wk Dk A^(-1) Dk') / pbDimension*tabNk
 			_tabLambda[k] = _tabWk[k]->trace_this_O_Sm1_O(_tabOrientation[k], _tabShape[k]);
 			_tabLambda[k] /= (_pbDimension * tabNk[k]);
 
@@ -480,7 +474,7 @@ void GaussianGeneralParameter::computeTabSigma_Lk_Dk_A_Dk() {
 				THROW(NumericException, errorSigmaConditionNumber);
 			}
 
-			(*_tabOrientation[k]) = (tabU[k]); //Dk = tabOrientationk = tabUk
+			(*_tabOrientation[k]) = (tabU[k]); // Dk = tabOrientationk = tabUk
 			_tabSigma[k]->compute_as__multi_O_S_O(_tabLambda[k], _tabOrientation[k], _tabShape[k]);
 		}
 
@@ -490,21 +484,21 @@ void GaussianGeneralParameter::computeTabSigma_Lk_Dk_A_Dk() {
 			delete tabU[k];
 			tabU[k] = NULL;
 		}
-		delete [] tabU;
-		delete [] tabS;
+		delete[] tabU;
+		delete[] tabS;
 		delete Shape;
 		delete S;
 	}
 
-	catch (Exception&errorType) {
+	catch (Exception &errorType) {
 		for (k = 0; k < _nbCluster; k++) {
 			delete tabS[k];
 			tabS[k] = NULL;
 			delete tabU[k];
 			tabU[k] = NULL;
 		}
-		delete [] tabU;
-		delete [] tabS;
+		delete[] tabU;
+		delete[] tabS;
 		delete Shape;
 		delete S;
 		throw;
@@ -514,13 +508,14 @@ void GaussianGeneralParameter::computeTabSigma_Lk_Dk_A_Dk() {
 /************************/
 /* computeTabSigma_Lk_C */
 /************************/
-void GaussianGeneralParameter::computeTabSigma_Lk_C() {
+void GaussianGeneralParameter::computeTabSigma_Lk_C()
+{
 
 	int64_t k;
-	double * tabNk = _model->getTabNk();
-	SymmetricMatrix * C = new SymmetricMatrix(_pbDimension); //Id
-	Matrix * R = new SymmetricMatrix(_pbDimension);
-	Matrix * Inv;
+	double *tabNk = _model->getTabNk();
+	SymmetricMatrix *C = new SymmetricMatrix(_pbDimension); // Id
+	Matrix *R = new SymmetricMatrix(_pbDimension);
+	Matrix *Inv;
 	Inv = new SymmetricMatrix(_pbDimension);
 	double logDet, detR;
 	int64_t iter = 5;
@@ -542,7 +537,7 @@ void GaussianGeneralParameter::computeTabSigma_Lk_C() {
 
 			C->inverse(Inv);
 			for (k = 0; k < _nbCluster; k++) {
-				//lambdak = trace(Wk C^(-1)) / pbDimension * tabNk
+				// lambdak = trace(Wk C^(-1)) / pbDimension * tabNk
 				_tabLambda[k] = _tabWk[k]->compute_trace_W_C(Inv);
 				_tabLambda[k] /= (_pbDimension * tabNk[k]);
 
@@ -564,8 +559,7 @@ void GaussianGeneralParameter::computeTabSigma_Lk_C() {
 		R = NULL;
 		delete Inv;
 		Inv = NULL;
-	}
-	catch (Exception&errorType) {
+	} catch (Exception &errorType) {
 		delete C;
 		C = NULL;
 		delete R;
@@ -579,21 +573,22 @@ void GaussianGeneralParameter::computeTabSigma_Lk_C() {
 /******************************/
 /* computeTabSigma_L_D_Ak_D() */
 /******************************/
-void GaussianGeneralParameter::computeTabSigma_L_D_Ak_D() {
-	GaussianData * data = _model->getGaussianData();
+void GaussianGeneralParameter::computeTabSigma_L_D_Ak_D()
+{
+	GaussianData *data = _model->getGaussianData();
 	int64_t k;
 	int64_t iter = 5;
 	double diff, FOld, F;
 	double sumTraceM = 0.0;
 	double lambda, logDet, DetDiagQtmp;
-	DiagMatrix * Shape_0 = new DiagMatrix(_pbDimension); //Id
+	DiagMatrix *Shape_0 = new DiagMatrix(_pbDimension); // Id
 
 	/* Flury algorithm                                                          */
 	/* SVD Decomposition of Cluster Scattering Matrix (Symmetric) Wk: Wk=U*S*U' */
 	/* Orientation matrix initialisation: _tabOrientation                       */
 	try {
 		(*Shape_0) = (_tabShape[0]);
-		_tabWk[0]-> computeSVD(_tabShape[0], _tabOrientation[0]);
+		_tabWk[0]->computeSVD(_tabShape[0], _tabOrientation[0]);
 		(*_tabShape[0]) = (Shape_0);
 
 		/* Compute Lambda: _lambda */
@@ -642,8 +637,7 @@ void GaussianGeneralParameter::computeTabSigma_L_D_Ak_D() {
 		}
 		delete Shape_0;
 
-	}
-	catch (Exception&errorType) {
+	} catch (Exception &errorType) {
 		delete Shape_0;
 		Shape_0 = NULL;
 		throw;
@@ -653,16 +647,17 @@ void GaussianGeneralParameter::computeTabSigma_L_D_Ak_D() {
 /*****************************/
 /* computeTabSigma_Lk_D_Ak_D */
 /*****************************/
-void GaussianGeneralParameter::computeTabSigma_Lk_D_Ak_D() {
+void GaussianGeneralParameter::computeTabSigma_Lk_D_Ak_D()
+{
 
-	double * tabNk = _model->getTabNk();
+	double *tabNk = _model->getTabNk();
 	int64_t k, iter = 5;
 
 	/* Flury algorithm                                                          */
 	/* SVD Decomposition of Cluster Scattering Matrix (Symmetric) Wk: Wk=U*S*U' */
 	//((SymmetricMatrix *) _tabWk[0]) -> computeSVD(_tabShape[0], _tabOrientation[0]);
 
-	_tabWk[0] -> computeSVD(_tabShape[0], _tabOrientation[0]);
+	_tabWk[0]->computeSVD(_tabShape[0], _tabOrientation[0]);
 
 	double diff = 10.0;
 	double F = 0.0;
@@ -673,9 +668,8 @@ void GaussianGeneralParameter::computeTabSigma_Lk_D_Ak_D() {
 		/* Compute Shape matrix: _tabShape[k] */
 		/* Qtmp = D*Wk^-1*D'                  */
 		for (k = 0; k < _nbCluster; k++) {
-			_tabWk[k]->computeShape_as__diag_Ot_this_O(
-					_tabShape[k], _tabOrientation[0], tabNk[k]);
-			//logDet = (_tabShape[k])->determinant(minDeterminantShapeValueError);
+			_tabWk[k]->computeShape_as__diag_Ot_this_O(_tabShape[k], _tabOrientation[0], tabNk[k]);
+			// logDet = (_tabShape[k])->determinant(minDeterminantShapeValueError);
 		}
 		FOld = F;
 		F = flury(F);
@@ -697,7 +691,8 @@ void GaussianGeneralParameter::computeTabSigma_Lk_D_Ak_D() {
 //------------------------------------------------/
 /* Variance estimator for each of general model  */
 //------------------------------------------------/
-void GaussianGeneralParameter::computeTabSigma() {
+void GaussianGeneralParameter::computeTabSigma()
+{
 	switch (_modelType->_nameModel) {
 
 	case (Gaussian_p_L_C):
@@ -744,7 +739,8 @@ void GaussianGeneralParameter::computeTabSigma() {
 // Flury Algorithm
 //----------------
 // TODO: provide references
-double GaussianGeneralParameter::flury(double F) {
+double GaussianGeneralParameter::flury(double F)
+{
 
 	// coefficients de la matrice a diagonaliser
 	//       [ a     b ]
@@ -759,14 +755,14 @@ double GaussianGeneralParameter::flury(double F) {
 	int64_t k, il, im, iter = 0;
 	double diff = 10;
 	double FOld, tmp, tmp2, termesHorsDiag, termesDiag;
-	double * Wk_store;
+	double *Wk_store;
 	int64_t p, q, r;
-	double * tabShape_k_store;
-	double * Ori = _tabOrientation[0]->getStore();
-	GaussianData * data = _model->getGaussianData();
-	double * D_im = data->getTmpTabOfSizePbDimension();
-	//double * D_il = new double[_pbDimension];
-	std::unique_ptr<double[]> D_il(new double[_pbDimension]);    
+	double *tabShape_k_store;
+	double *Ori = _tabOrientation[0]->getStore();
+	GaussianData *data = _model->getGaussianData();
+	double *D_im = data->getTmpTabOfSizePbDimension();
+	// double * D_il = new double[_pbDimension];
+	std::unique_ptr<double[]> D_il(new double[_pbDimension]);
 	int64_t il_p, im_p;
 	double iSim_iSil_k;
 
@@ -780,7 +776,7 @@ double GaussianGeneralParameter::flury(double F) {
 				il_p = il;
 				im_p = im;
 				for (p = 0; p < _pbDimension; p++) {
-					D_il[p] = Ori[il_p]; // remplir la colonne 1 :         
+					D_il[p] = Ori[il_p]; // remplir la colonne 1 :
 					D_im[p] = Ori[im_p]; // remplir la colonne 2 :
 
 					il_p += _pbDimension;
@@ -788,8 +784,8 @@ double GaussianGeneralParameter::flury(double F) {
 				}
 
 				/* Compute matrix R where q1 is the second eigen vector */
-				//RR_store = RR.Store();
-				//initToZero(RR_store,4);
+				// RR_store = RR.Store();
+				// initToZero(RR_store,4);
 
 				a = 0.0;
 				b = 0.0;
@@ -797,7 +793,7 @@ double GaussianGeneralParameter::flury(double F) {
 
 				for (k = 0; k < _nbCluster; k++) {
 
-					//Wk_store         = ((SymmetricMatrix *)_tabWk[k])->getStore();
+					// Wk_store         = ((SymmetricMatrix *)_tabWk[k])->getStore();
 					Wk_store = _tabWk[k]->getSymmetricStore();
 					tabShape_k_store = _tabShape[k]->getStore();
 					iSim_iSil_k = 1.0 / tabShape_k_store[il] - 1.0 / tabShape_k_store[im];
@@ -829,7 +825,7 @@ double GaussianGeneralParameter::flury(double F) {
 					termesDiag *= iSim_iSil_k;
 					b += termesDiag;
 
-					// remplir RR(2,2)   
+					// remplir RR(2,2)
 					termesHorsDiag = termesDiag = 0.0;
 					for (p = 0, r = 0; p < _pbDimension; p++, r++) {
 						tmp = D_im[p];
@@ -841,16 +837,13 @@ double GaussianGeneralParameter::flury(double F) {
 					termesDiag += 2 * termesHorsDiag;
 					termesDiag *= iSim_iSil_k;
 					c += termesDiag;
-
 				}
 
 				tmp = a - c;
 				eigenValueMoins = (a + c - sqrt(tmp * tmp + 4 * b * b)) / 2.0;
 
-				eigenVectorMoins_1 = b 
-						/ sqrt(b * b + (a - eigenValueMoins)*(a - eigenValueMoins));
-				eigenVectorMoins_2 = -(a - eigenValueMoins) 
-						/ sqrt(b * b + (a - eigenValueMoins)*(a - eigenValueMoins));
+				eigenVectorMoins_1 = b / sqrt(b * b + (a - eigenValueMoins) * (a - eigenValueMoins));
+				eigenVectorMoins_2 = -(a - eigenValueMoins) / sqrt(b * b + (a - eigenValueMoins) * (a - eigenValueMoins));
 
 				// remplir la colonne d'indice il avec Dlm * q1
 				il_p = il;
@@ -861,7 +854,6 @@ double GaussianGeneralParameter::flury(double F) {
 					il_p += _pbDimension;
 					im_p += _pbDimension;
 				}
-
 			}
 		}
 
@@ -879,32 +871,33 @@ double GaussianGeneralParameter::flury(double F) {
 		iter++;
 	}
 
-	//delete[] D_il;
+	// delete[] D_il;
 	return F;
 }
 
 //-------------------
-//getLogLikelihoodOne
+// getLogLikelihoodOne
 //-------------------
-double GaussianGeneralParameter::getLogLikelihoodOne() const {
+double GaussianGeneralParameter::getLogLikelihoodOne() const
+{
 	/* Compute log-likelihood for one cluster
 	   useful for NEC criterion */
 
 	/* Initialization */
 	int64_t nbSample = _model->getNbSample();
 	int64_t i;
-	GaussianData * data = _model->getGaussianData();
+	GaussianData *data = _model->getGaussianData();
 	double logLikelihoodOne; // Log-likelihood for k=1
-	//double * Mean = new double[_pbDimension];
+	// double * Mean = new double[_pbDimension];
 	std::unique_ptr<double[]> Mean(new double[_pbDimension]);
-	double ** y = data->_yStore;
-	double * yi;
-	//SymmetricMatrix * Sigma = new SymmetricMatrix(_pbDimension); //Id
-	//SymmetricMatrix * W = new SymmetricMatrix(_pbDimension, 0.0); // 0.0
-	std::unique_ptr<SymmetricMatrix> Sigma(new SymmetricMatrix(_pbDimension)); //Id
+	double **y = data->_yStore;
+	double *yi;
+	// SymmetricMatrix * Sigma = new SymmetricMatrix(_pbDimension); //Id
+	// SymmetricMatrix * W = new SymmetricMatrix(_pbDimension, 0.0); // 0.0
+	std::unique_ptr<SymmetricMatrix> Sigma(new SymmetricMatrix(_pbDimension));  // Id
 	std::unique_ptr<SymmetricMatrix> W(new SymmetricMatrix(_pbDimension, 0.0)); // 0.0
 	double norme;
-	double * weight = data->_weight;
+	double *weight = data->_weight;
 
 	//  Mean Estimator (empirical estimator)
 	double totalWeight = data->_weightTotal;
@@ -914,7 +907,7 @@ double GaussianGeneralParameter::getLogLikelihoodOne() const {
 	/* Compute the Cluster Scattering Matrix W */
 
 	int64_t p; // parcours
-	double * xiMoinsMuk = data->getTmpTabOfSizePbDimension();
+	double *xiMoinsMuk = data->getTmpTabOfSizePbDimension();
 
 	for (i = 0; i < nbSample; i++) {
 		yi = y[i];
@@ -931,11 +924,11 @@ double GaussianGeneralParameter::getLogLikelihoodOne() const {
 
 	// inverse of Sigma
 
-	//SymmetricMatrix * SigmaMoins1 = new SymmetricMatrix(_pbDimension);
-	Matrix* SigmaMoins1_p = NULL;
-	//SigmaMoins1->inverse(Sigma);// virtual
+	// SymmetricMatrix * SigmaMoins1 = new SymmetricMatrix(_pbDimension);
+	Matrix *SigmaMoins1_p = NULL;
+	// SigmaMoins1->inverse(Sigma);// virtual
 	Sigma->inverse(SigmaMoins1_p);
-    std::unique_ptr<Matrix> SigmaMoins1(SigmaMoins1_p); //only for a safe deletion of SigmaMoins1_p
+	std::unique_ptr<Matrix> SigmaMoins1(SigmaMoins1_p); // only for a safe deletion of SigmaMoins1_p
 	NumericException error = NumericException(minDeterminantSigmaValueError);
 	double detSigma = Sigma->determinant(error); // virtual
 
@@ -954,24 +947,25 @@ double GaussianGeneralParameter::getLogLikelihoodOne() const {
 	logLikelihoodOne += totalWeight * (data->getPbDimensionLog2Pi() + log(detSigma));
 	logLikelihoodOne *= -0.5;
 
-	//delete W;
-	//delete Sigma;
-	//delete SigmaMoins1;
+	// delete W;
+	// delete Sigma;
+	// delete SigmaMoins1;
 
-	//delete[] Mean;
+	// delete[] Mean;
 
 	return logLikelihoodOne;
 }
 
 //----------------
-//getFreeParameter
+// getFreeParameter
 //----------------
-int64_t GaussianGeneralParameter::getFreeParameter() const {
-	int64_t nbParameter; // Number of parameters //
-	int64_t k = _nbCluster; // Sample size          //
+int64_t GaussianGeneralParameter::getFreeParameter() const
+{
+	int64_t nbParameter;      // Number of parameters //
+	int64_t k = _nbCluster;   // Sample size          //
 	int64_t d = _pbDimension; // Sample dimension     //
 
-	int64_t alphaR = k*d; // alpha for for models with Restrainct proportions (Gaussian_p_...)
+	int64_t alphaR = k * d;           // alpha for for models with Restrainct proportions (Gaussian_p_...)
 	int64_t alphaF = (k * d) + k - 1; // alpha for models with Free proportions (Gaussian_pk_...)
 	int64_t beta = d * (d + 1) / 2;
 
@@ -983,7 +977,7 @@ int64_t GaussianGeneralParameter::getFreeParameter() const {
 		nbParameter = alphaR + beta + (k - 1);
 		break;
 	case (Gaussian_p_L_D_Ak_D):
-		nbParameter = alphaR + beta + (k - 1)*(d - 1);
+		nbParameter = alphaR + beta + (k - 1) * (d - 1);
 		break;
 	case (Gaussian_p_Lk_D_Ak_D):
 		nbParameter = alphaR + beta + (k - 1) * d;
@@ -992,7 +986,7 @@ int64_t GaussianGeneralParameter::getFreeParameter() const {
 		nbParameter = alphaR + (k * beta) - (k - 1) * d;
 		break;
 	case (Gaussian_p_Lk_Dk_A_Dk):
-		nbParameter = alphaR + (k * beta) - (k - 1)*(d - 1);
+		nbParameter = alphaR + (k * beta) - (k - 1) * (d - 1);
 		break;
 	case (Gaussian_p_L_Ck):
 		nbParameter = alphaR + (k * beta) - (k - 1);
@@ -1007,7 +1001,7 @@ int64_t GaussianGeneralParameter::getFreeParameter() const {
 		nbParameter = alphaF + beta + (k - 1);
 		break;
 	case (Gaussian_pk_L_D_Ak_D):
-		nbParameter = alphaF + beta + (k - 1)*(d - 1);
+		nbParameter = alphaF + beta + (k - 1) * (d - 1);
 		break;
 	case (Gaussian_pk_Lk_D_Ak_D):
 		nbParameter = alphaF + beta + (k - 1) * d;
@@ -1016,7 +1010,7 @@ int64_t GaussianGeneralParameter::getFreeParameter() const {
 		nbParameter = alphaF + (k * beta) - (k - 1) * d;
 		break;
 	case (Gaussian_pk_Lk_Dk_A_Dk):
-		nbParameter = alphaF + (k * beta) - (k - 1)*(d - 1);
+		nbParameter = alphaF + (k * beta) - (k - 1) * (d - 1);
 		break;
 	case (Gaussian_pk_L_Ck):
 		nbParameter = alphaF + (k * beta) - (k - 1);
