@@ -6,7 +6,7 @@
 
 /***************************************************************************
     This file is part of MIXMOD
-    
+
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,14 +20,15 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org                                                                                               
+    All informations available on : http://www.mixmod.org
 ***************************************************************************/
 #ifndef XEMDIAGMATRIX_H
 #define XEMDIAGMATRIX_H
 
 #include "mixmod/Matrix/Matrix.h"
 
-namespace XEM {
+namespace XEM
+{
 
 // pre-declaration
 class GeneralMatrix;
@@ -37,10 +38,10 @@ class GeneralMatrix;
   @author F Langrognet & A Echenim
  */
 
-class DiagMatrix : public Matrix {
+class DiagMatrix : public Matrix
+{
 
 public:
-
 	/// Default constructor
 	DiagMatrix();
 
@@ -48,128 +49,119 @@ public:
 	/// default value  = Id
 	DiagMatrix(int64_t pbDimension, double d = 1.0);
 
-	DiagMatrix(DiagMatrix * A);
+	DiagMatrix(DiagMatrix *A);
 
 	/// Desctructor
 	virtual ~DiagMatrix();
 
 	/// compute determinant of diagonal matrix
-	double determinant(Exception& errorType);
+	double determinant(Exception &errorType);
 	/// return store of diagonal matrix
-	double * getStore();
+	double *getStore();
 	/// compute inverse of diagonal matrix
-	void inverse(Matrix * & A);
+	void inverse(Matrix *&A);
 
-	void compute_product_Lk_Wk(Matrix* Wk, double L);
+	void compute_product_Lk_Wk(Matrix *Wk, double L);
 
-	/// compute (x - mean)' this (x - mean) 
-	double norme(double * xMoinsMean);
+	/// compute (x - mean)' this (x - mean)
+	double norme(double *xMoinsMean);
 
 	/// (this) will be A / d
-	void equalToMatrixDividedByDouble(Matrix * A, double d);
+	void equalToMatrixDividedByDouble(Matrix *A, double d);
 
 	/// this = matrix * d
-	void equalToMatrixMultiplyByDouble(Matrix*D, double d);
+	void equalToMatrixMultiplyByDouble(Matrix *D, double d);
 
-	///compute singular vector decomposition
-	void computeSVD(DiagMatrix* & S, GeneralMatrix* & O);
+	/// compute singular vector decomposition
+	void computeSVD(DiagMatrix *&S, GeneralMatrix *&O);
 
 	/// compute trace of general matrix
 	double computeTrace();
 
 	/// add :  cik * xMoinsMean * xMoinsMean'  to this
-	void add(double * xMoinsMean, double cik);
+	void add(double *xMoinsMean, double cik);
 
 	// add : diag( cik * xMoinsMean * xMoinsMean' )  to this
-	//void addDiag(double * xMoinsMean, double cik);
+	// void addDiag(double * xMoinsMean, double cik);
 
-	/// set the value of (d x Identity) to this  
-	void operator=(const double& d);
+	/// set the value of (d x Identity) to this
+	void operator=(const double &d);
 	/// this = this / (d * Identity)
-	void operator/=(const double& d);
+	void operator/=(const double &d);
 	/// this = this * (d * Identity)
-	void operator*=(const double& d);
+	void operator*=(const double &d);
 	/// this = this + matrix
-	void operator+=(Matrix* M);
+	void operator+=(Matrix *M);
 	/// this = matrix
-	void operator=(Matrix* M);
+	void operator=(Matrix *M);
 
 	/// Return store of a spherical matrix in a diagonal one
-	double putSphericalValueInStore(double & store);
+	double putSphericalValueInStore(double &store);
 	/// Add store of a spherical matrix in a diagonal one
-	double addSphericalValueInStore(double & store);
+	double addSphericalValueInStore(double &store);
 
 	double getSphericalStore();
 
 	/// Return store of a diagonal matrix
-	double* putDiagonalValueInStore(double * store);
+	double *putDiagonalValueInStore(double *store);
 	/// Add store of a diagonal matrix in a diagonal one
-	double* addDiagonalValueInStore(double * store);
+	double *addDiagonalValueInStore(double *store);
 
-	double* getDiagonalStore();
+	double *getDiagonalStore();
 
 	/// Return store of a diagonal matrix
-	double* putSymmetricValueInStore(double * store);
+	double *putSymmetricValueInStore(double *store);
 	/// Add store of a diagonal matrix in a diagonal one
-	double* addSymmetricValueInStore(double * store);
+	double *addSymmetricValueInStore(double *store);
 
-	double* getSymmetricStore();
+	double *getSymmetricStore();
 
 	/// Return store of a diagonal matrix
-	double* putGeneralValueInStore(double * store);
+	double *putGeneralValueInStore(double *store);
 	/// Add store of a diagonal matrix in a diagonal one
-	double* addGeneralValueInStore(double * store);
+	double *addGeneralValueInStore(double *store);
 
-	double* getGeneralStore();
+	double *getGeneralStore();
 
 	/// read general matrix in an input file
-	void input(std::ifstream & fi);
-	virtual void input(double ** variances);
+	void input(std::ifstream &fi);
+	virtual void input(double **variances);
 
-	///set store
-	void setSymmetricStore(double * store);
-	void setGeneralStore(double * store);
-	void setDiagonalStore(double * store);
+	/// set store
+	void setSymmetricStore(double *store);
+	void setGeneralStore(double *store);
+	void setDiagonalStore(double *store);
 	void setSphericalStore(double store);
-	double** storeToArray() const;
+	double **storeToArray() const;
 
 	/// gives : det(diag(this))
-	double detDiag(Exception& errorType);
+	double detDiag(Exception &errorType);
 
-	void compute_as__multi_O_S_O(double multi, GeneralMatrix* & O, DiagMatrix *& S);
-	double trace_this_O_Sm1_O(GeneralMatrix* & O, DiagMatrix* & S);
-	double compute_trace_W_C(Matrix * C);
-	void computeShape_as__diag_Ot_this_O(DiagMatrix* & Shape, GeneralMatrix* & Ori, double diviseur = 1.0);
+	void compute_as__multi_O_S_O(double multi, GeneralMatrix *&O, DiagMatrix *&S);
+	double trace_this_O_Sm1_O(GeneralMatrix *&O, DiagMatrix *&S);
+	double compute_trace_W_C(Matrix *C);
+	void computeShape_as__diag_Ot_this_O(DiagMatrix *&Shape, GeneralMatrix *&Ori, double diviseur = 1.0);
 
-	///sort diagonal matrix in decreasing order
+	/// sort diagonal matrix in decreasing order
 	void sortDiagMatrix();
-	
+
 protected:
-
-	double * _store;
-
+	double *_store;
 };
 
-inline double * DiagMatrix::getStore() {
-	return _store;
-}
+inline double *DiagMatrix::getStore() { return _store; }
 
-inline void DiagMatrix::setSymmetricStore(double * /*store*/) {
-	THROW(OtherException, wrongMatrixType);
-}
+inline void DiagMatrix::setSymmetricStore(double * /*store*/) { THROW(OtherException, wrongMatrixType); }
 
-inline void DiagMatrix::setGeneralStore(double * /*store*/) {
-	THROW(OtherException, wrongMatrixType);
-}
+inline void DiagMatrix::setGeneralStore(double * /*store*/) { THROW(OtherException, wrongMatrixType); }
 
-inline void DiagMatrix::setDiagonalStore(double * store) {
+inline void DiagMatrix::setDiagonalStore(double *store)
+{
 	//_store = store;
 	recopyTab(store, _store, _s_pbDimension);
 }
 
-inline void DiagMatrix::setSphericalStore(double /*store*/) {
-	THROW(OtherException, wrongMatrixType);
-}
+inline void DiagMatrix::setSphericalStore(double /*store*/) { THROW(OtherException, wrongMatrixType); }
 
 }
 
