@@ -6,7 +6,7 @@
 
 /***************************************************************************
     This file is part of MIXMOD
-    
+
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,39 +20,34 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org                                                                                               
+    All informations available on : http://www.mixmod.org
 ***************************************************************************/
 #include "mixmod/Matrix/Matrix.h"
 #include "mixmod/Utilities/maths/SelectLibrary.h"
 
-namespace XEM {
+namespace XEM
+{
 
 //------------
 // Constructor
 //------------
-Matrix::Matrix() {
-	_s_pbDimension = 0;
-}
+Matrix::Matrix() { _s_pbDimension = 0; }
 
-Matrix::Matrix(int64_t pbDimension) {
-	_s_pbDimension = pbDimension;
-}
+Matrix::Matrix(int64_t pbDimension) { _s_pbDimension = pbDimension; }
 
-Matrix::Matrix(Matrix * A) {
-	_s_pbDimension = A->getPbDimension();
-}
+Matrix::Matrix(Matrix *A) { _s_pbDimension = A->getPbDimension(); }
 
 //----------
-//Destructor
+// Destructor
 //----------
-Matrix::~Matrix() {
-}
+Matrix::~Matrix() {}
 
-void Matrix::edit(std::ostream& flux, std::string before) {
+void Matrix::edit(std::ostream &flux, std::string before)
+{
 
 	int64_t i;
 	int64_t j;
-	double** store = storeToArray();
+	double **store = storeToArray();
 	for (i = 0; i < _s_pbDimension; i++) {
 		flux << '\t' << '\t' << '\t' << '\t';
 		for (j = 0; j < _s_pbDimension; j++)
@@ -61,19 +56,19 @@ void Matrix::edit(std::ostream& flux, std::string before) {
 	}
 
 	for (i = 0; i < _s_pbDimension; i++) {
-		delete [] store[i];
+		delete[] store[i];
 		store[i] = NULL;
 	}
-	delete [] store;
+	delete[] store;
 	store = NULL;
 
 	/*  flux << before << flush;
-		  for(j=0;j<i;j++){
-		flux << "0.000000 " << flush;
+	      for(j=0;j<i;j++){
+	    flux << "0.000000 " << flush;
 	  }
 	  flux << _store << " "<< flush;
 	  for(j=i+1;j<_s_pbDimension;j++){
-		flux << "0.000000 " << flush;
+	    flux << "0.000000 " << flush;
 	  }
 	  flux << endl;
 	}*/
