@@ -6,7 +6,7 @@
 
 /***************************************************************************
     This file is part of MIXMOD
-    
+
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,36 +20,35 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org                                                                                               
+    All informations available on : http://www.mixmod.org
 ***************************************************************************/
 #include "mixmod/Utilities/Error.h"
 
-namespace XEM {
+namespace XEM
+{
 
 //-----------
-//Constructor
+// Constructor
 //-----------
-Error::Error() : _errorType(NOERROR.clone()) {
-}
+Error::Error() : _errorType(NOERROR.clone()) {}
 
 //-----------
-//Constructor
+// Constructor
 //-----------
-Error::Error(Exception& errorType) : _errorType((((errorType)).clone())) {
-}
+Error::Error(Exception &errorType) : _errorType((((errorType)).clone())) {}
 
 //----------
-//Destructor
+// Destructor
 //----------
-Error::~Error() {
-	if (_errorType) delete _errorType;
+Error::~Error()
+{
+	if (_errorType)
+		delete _errorType;
 }
 
 //---
-//Run
+// Run
 //---
-void Error::run() {
-	((Exception*) _errorType)->run();
-}
+void Error::run() { ((Exception *)_errorType)->run(); }
 
 }
