@@ -6,7 +6,7 @@
 
 /***************************************************************************
     This file is part of MIXMOD
-    
+
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,7 +20,7 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org                                                                                               
+    All informations available on : http://www.mixmod.org
 ***************************************************************************/
 /**
   @file Error.h
@@ -33,43 +33,42 @@
 
 #include "mixmod/Utilities/Util.h"
 
-namespace XEM {
+namespace XEM
+{
 
 /**
   @brief Base class for Error(s)
   @author F Langrognet
  */
-class Error {
+class Error
+{
 
 public:
-
 	/// Default constructor
 	Error();
 
 	/// Constructor
-	Error(Exception & errorType);
+	Error(Exception &errorType);
 
 	/// Destructor
 	~Error();
 
 	// setter
-	inline void setError(Exception & errorType) {
+	inline void setError(Exception &errorType)
+	{
 		delete _errorType;
 		_errorType = errorType.clone();
 	}
 
 	// getter
-	inline Exception& getError() const {
-		return *_errorType;
-	}
+	inline Exception &getError() const { return *_errorType; }
 
 	/// Run method (for debug)
 	void run();
 
 private:
-
-	/// Type of error	
-	Exception * _errorType;
+	/// Type of error
+	Exception *_errorType;
 };
 
 }
