@@ -6,7 +6,7 @@
 
 /***************************************************************************
     This file is part of MIXMOD
-    
+
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,7 +20,7 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org                                                                                               
+    All informations available on : http://www.mixmod.org
 ***************************************************************************/
 /**
  * @file ExampleDataUtil
@@ -31,31 +31,32 @@
 #ifndef XEM_EXAMPLEDATAUTIL_H
 #define XEM_EXAMPLEDATAUTIL_H
 
-#include "mixmod/Kernel/IO/Data.h"
-#include "mixmod/Kernel/IO/CompositeData.h"
-#include "mixmod/Kernel/IO/GaussianData.h"
-#include "mixmod/Kernel/IO/BinaryData.h"
-#include "mixmod/Kernel/IO/DataDescription.h"
-#include "mixmod/Kernel/IO/LabelDescription.h"
 #include "mixmod/Clustering/ClusteringInput.h"
 #include "mixmod/DiscriminantAnalysis/Learn/LearnInput.h"
-#include "mixmod/DiscriminantAnalysis/Predict/PredictInput.h"
 #include "mixmod/DiscriminantAnalysis/Learn/LearnModelOutput.h"
+#include "mixmod/DiscriminantAnalysis/Predict/PredictInput.h"
+#include "mixmod/Kernel/IO/BinaryData.h"
+#include "mixmod/Kernel/IO/CompositeData.h"
+#include "mixmod/Kernel/IO/Data.h"
+#include "mixmod/Kernel/IO/DataDescription.h"
+#include "mixmod/Kernel/IO/GaussianData.h"
+#include "mixmod/Kernel/IO/LabelDescription.h"
 #include "mixmod/Kernel/Model/ModelType.h"
 
-namespace XEM {
+namespace XEM
+{
 
 // @param fileName Input file name. It should be CSV file with first row containing type for corresponding column.
 // Type can be 'C' for continuous (gaussian) or 'B' for binary (categories).
-ClusteringInput* getClusteringInput(string fileName, const vector<int64_t>& nbCluster);
-LearnInput* getLearnInput(string fileName);
-PredictInput* getPredictInput(string fileName, LearnModelOutput* lOutput);
+ClusteringInput *getClusteringInput(string fileName, const vector<int64_t> &nbCluster);
+LearnInput *getLearnInput(string fileName);
+PredictInput *getPredictInput(string fileName, LearnModelOutput *lOutput);
 
-template<class T>
-inline void DeleteData(T ** data, int nbSample){
-	for (int i=0; i<nbSample; i++)
-		delete [] data[i];
-	delete [] data;
+template <class T> inline void DeleteData(T **data, int nbSample)
+{
+	for (int i = 0; i < nbSample; i++)
+		delete[] data[i];
+	delete[] data;
 }
 
 }
