@@ -6,7 +6,7 @@
 
 /***************************************************************************
     This file is part of MIXMOD
-    
+
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,7 +20,7 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org                                                                                               
+    All informations available on : http://www.mixmod.org
 ***************************************************************************/
 /** @file XEMDCVException.h
  *  @brief Exception class for DCV errors.
@@ -32,37 +32,39 @@
 
 #include "mixmod/Utilities/exceptions/Exception.h"
 
-namespace XEM {
+namespace XEM
+{
 
-class DCVException : public Exception {
+class DCVException : public Exception
+{
 
 public:
-	
-	DCVException(std::string, int, DCVError) throw ();
-	Exception * clone() throw ();
-	DCVException(DCVError) throw ();
-	virtual const char* what() const throw ();
-	virtual bool operator==(const Exception&) const throw ();
-	virtual void run(std::ostream & flux = std::cout) const throw ();
+	DCVException(std::string, int, DCVError) throw();
+	Exception *clone() throw();
+	DCVException(DCVError) throw();
+	virtual const char *what() const throw();
+	virtual bool operator==(const Exception &) const throw();
+	virtual void run(std::ostream &flux = std::cout) const throw();
 
-	virtual ~DCVException() throw () {
+	virtual ~DCVException() throw() {}
+
+	static std::map<DCVError, const char *> create_map()
+	{
+		std::map<DCVError, const char *> m;
+		m.insert(
+		    std::make_pair(wrongDCVinitBlocks, "DCV error : wrong init block specification, must be either RANDOM or DIAG"));
+		m.insert(std::make_pair(wrongDCVnumberOfBlocks,
+		                        "DCV error : wrong number of blocks, must be between 2 and the number of samples"));
+		m.insert(std::make_pair(DCVmustBeDIAG, "DCV error : in this situation DCV init block specification must be DIAG"));
+		m.insert(std::make_pair(forbiddenCallToGetBestCVModel,
+		                        "DCV error : call to getBestCVModel is forbidden in the current context"));
+
+		return m;
 	}
 
-  static std::map<DCVError, const char*> create_map()
-  {
-    std::map<DCVError, const char*> m;
-    m.insert(std::make_pair(wrongDCVinitBlocks, "DCV error : wrong init block specification, must be either RANDOM or DIAG"));
-    m.insert(std::make_pair(wrongDCVnumberOfBlocks, "DCV error : wrong number of blocks, must be between 2 and the number of samples"));
-    m.insert(std::make_pair(DCVmustBeDIAG, "DCV error : in this situation DCV init block specification must be DIAG"));
-    m.insert(std::make_pair(forbiddenCallToGetBestCVModel, "DCV error : call to getBestCVModel is forbidden in the current context"));
-
-    return m;
-  }
-
-	static std::map<DCVError, const char*> mapErrorMsg;
+	static std::map<DCVError, const char *> mapErrorMsg;
 
 protected:
-	
 	DCVError _errorType;
 };
 
